"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Security/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Security,
)
from cdpkit.protocol.base import CDPEvent


class CertificateError(CDPEvent):
    """ There is a certificate error. If overriding certificate errors is enabled, then it should be
    handled with the `handleCertificateError` command. Note: this event does not fire if the
    certificate error has been allowed internally. Only one client per target should override
    certificate errors at the same time. """

    eventId: int
    errorType: str
    requestURL: str


class VisibleSecurityStateChanged(CDPEvent):
    """ The security state of the page changed. """

    visibleSecurityState: Security.VisibleSecurityState


class SecurityStateChanged(CDPEvent):
    """ The security state of the page changed. No longer being sent. """

    securityState: Security.SecurityState
    schemeIsCryptographic: bool  # deprecated
    explanations: list[Security.SecurityStateExplanation]  # deprecated
    insecureContentStatus: Security.InsecureContentStatus  # deprecated
    summary: str | None = None  # deprecated



from .events import WorkerErrorReported, WorkerRegistrationUpdated, WorkerVersionUpdated
from .methods import (
    DeliverPushMessage,
    Disable,
    DispatchPeriodicSyncEvent,
    DispatchSyncEvent,
    Enable,
    SetForceUpdateOnPageLoad,
    SkipWaiting,
    StartWorker,
    StopAllWorkers,
    StopWorker,
    Unregister,
    UpdateRegistration,
)
from .types import (
    RegistrationID,
    ServiceWorkerErrorMessage,
    ServiceWorkerRegistration,
    ServiceWorkerVersion,
    ServiceWorkerVersionRunningStatus,
    ServiceWorkerVersionStatus,
)

__all__ = [
    RegistrationID,
    ServiceWorkerRegistration,
    ServiceWorkerVersionRunningStatus,
    ServiceWorkerVersionStatus,
    ServiceWorkerVersion,
    ServiceWorkerErrorMessage,
    WorkerErrorReported,
    WorkerRegistrationUpdated,
    WorkerVersionUpdated,
    DeliverPushMessage,
    Disable,
    DispatchSyncEvent,
    DispatchPeriodicSyncEvent,
    Enable,
    SetForceUpdateOnPageLoad,
    SkipWaiting,
    StartWorker,
    StopAllWorkers,
    StopWorker,
    Unregister,
    UpdateRegistration,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/LayerTree/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOM,
    LayerTree,
)
from cdpkit.protocol.base import CDPEvent


class LayerPainted(CDPEvent):

    layerId: LayerTree.LayerId
    clip: DOM.Rect


class LayerTreeDidChange(CDPEvent):

    layers: list[LayerTree.Layer] | None = None



from .events import AddHeapSnapshotChunk, HeapStatsUpdate, LastSeenObjectId, ReportHeapSnapshotProgress, ResetProfiles
from .methods import (
    AddInspectedHeapObject,
    CollectGarbage,
    Disable,
    Enable,
    GetHeapObjectId,
    GetObjectByHeapObjectId,
    GetSamplingProfile,
    StartSampling,
    StartTrackingHeapObjects,
    StopSampling,
    StopTrackingHeapObjects,
    TakeHeapSnapshot,
)
from .types import HeapSnapshotObjectId, SamplingHeapProfile, SamplingHeapProfileNode, SamplingHeapProfileSample

__all__ = [
    HeapSnapshotObjectId,
    SamplingHeapProfileNode,
    SamplingHeapProfileSample,
    SamplingHeapProfile,
    AddHeapSnapshotChunk,
    HeapStatsUpdate,
    LastSeenObjectId,
    ReportHeapSnapshotProgress,
    ResetProfiles,
    AddInspectedHeapObject,
    CollectGarbage,
    Disable,
    Enable,
    GetHeapObjectId,
    GetObjectByHeapObjectId,
    GetSamplingProfile,
    StartSampling,
    StartTrackingHeapObjects,
    StopSampling,
    StopTrackingHeapObjects,
    TakeHeapSnapshot,
]



from .events import EntryAdded
from .methods import Clear, Disable, Enable, StartViolationsReport, StopViolationsReport
from .types import LogEntry, ViolationSetting

__all__ = [
    LogEntry,
    ViolationSetting,
    EntryAdded,
    Clear,
    Disable,
    Enable,
    StartViolationsReport,
    StopViolationsReport,
]



from .events import DeviceRequestPrompted
from .methods import CancelPrompt, Disable, Enable, SelectPrompt
from .types import DeviceId, PromptDevice, RequestId

__all__ = [
    RequestId,
    DeviceId,
    PromptDevice,
    DeviceRequestPrompted,
    Enable,
    Disable,
    SelectPrompt,
    CancelPrompt,
]



from .events import (
    AttributionReportingReportSent,
    AttributionReportingSourceRegistered,
    AttributionReportingTriggerRegistered,
    AttributionReportingVerboseDebugReportSent,
    CacheStorageContentUpdated,
    CacheStorageListUpdated,
    IndexedDBContentUpdated,
    IndexedDBListUpdated,
    InterestGroupAccessed,
    InterestGroupAuctionEventOccurred,
    InterestGroupAuctionNetworkRequestCreated,
    SharedStorageAccessed,
    SharedStorageWorkletOperationExecutionFinished,
    StorageBucketCreatedOrUpdated,
    StorageBucketDeleted,
)
from .methods import (
    ClearCookies,
    ClearDataForOrigin,
    ClearDataForStorageKey,
    ClearSharedStorageEntries,
    ClearTrustTokens,
    DeleteSharedStorageEntry,
    DeleteStorageBucket,
    GetAffectedUrlsForThirdPartyCookieMetadata,
    GetCookies,
    GetInterestGroupDetails,
    GetRelatedWebsiteSets,
    GetSharedStorageEntries,
    GetSharedStorageMetadata,
    GetStorageKey,
    GetStorageKeyForFrame,
    GetTrustTokens,
    GetUsageAndQuota,
    OverrideQuotaForOrigin,
    ResetSharedStorageBudget,
    RunBounceTrackingMitigations,
    SendPendingAttributionReports,
    SetAttributionReportingLocalTestingMode,
    SetAttributionReportingTracking,
    SetCookies,
    SetInterestGroupAuctionTracking,
    SetInterestGroupTracking,
    SetProtectedAudienceKAnonymity,
    SetSharedStorageEntry,
    SetSharedStorageTracking,
    SetStorageBucketTracking,
    TrackCacheStorageForOrigin,
    TrackCacheStorageForStorageKey,
    TrackIndexedDBForOrigin,
    TrackIndexedDBForStorageKey,
    UntrackCacheStorageForOrigin,
    UntrackCacheStorageForStorageKey,
    UntrackIndexedDBForOrigin,
    UntrackIndexedDBForStorageKey,
)
from .types import (
    AttributionReportingAggregatableDebugReportingConfig,
    AttributionReportingAggregatableDebugReportingData,
    AttributionReportingAggregatableDedupKey,
    AttributionReportingAggregatableResult,
    AttributionReportingAggregatableTriggerData,
    AttributionReportingAggregatableValueDictEntry,
    AttributionReportingAggregatableValueEntry,
    AttributionReportingAggregationKeysEntry,
    AttributionReportingEventLevelResult,
    AttributionReportingEventReportWindows,
    AttributionReportingEventTriggerData,
    AttributionReportingFilterConfig,
    AttributionReportingFilterDataEntry,
    AttributionReportingFilterPair,
    AttributionReportingNamedBudgetCandidate,
    AttributionReportingNamedBudgetDef,
    AttributionReportingReportResult,
    AttributionReportingSourceRegistration,
    AttributionReportingSourceRegistrationResult,
    AttributionReportingSourceRegistrationTimeConfig,
    AttributionReportingSourceType,
    AttributionReportingTriggerDataMatching,
    AttributionReportingTriggerRegistration,
    AttributionScopesData,
    InterestGroupAccessType,
    InterestGroupAuctionEventType,
    InterestGroupAuctionFetchType,
    InterestGroupAuctionId,
    RelatedWebsiteSet,
    SerializedStorageKey,
    SharedStorageAccessMethod,
    SharedStorageAccessParams,
    SharedStorageAccessScope,
    SharedStorageEntry,
    SharedStorageMetadata,
    SharedStoragePrivateAggregationConfig,
    SharedStorageReportingMetadata,
    SharedStorageUrlWithMetadata,
    SignedInt64AsBase10,
    StorageBucket,
    StorageBucketInfo,
    StorageBucketsDurability,
    StorageType,
    TrustTokens,
    UnsignedInt64AsBase10,
    UnsignedInt128AsBase16,
    UsageForType,
)

__all__ = [
    SerializedStorageKey,
    StorageType,
    UsageForType,
    TrustTokens,
    InterestGroupAuctionId,
    InterestGroupAccessType,
    InterestGroupAuctionEventType,
    InterestGroupAuctionFetchType,
    SharedStorageAccessScope,
    SharedStorageAccessMethod,
    SharedStorageEntry,
    SharedStorageMetadata,
    SharedStoragePrivateAggregationConfig,
    SharedStorageReportingMetadata,
    SharedStorageUrlWithMetadata,
    SharedStorageAccessParams,
    StorageBucketsDurability,
    StorageBucket,
    StorageBucketInfo,
    AttributionReportingSourceType,
    UnsignedInt64AsBase10,
    UnsignedInt128AsBase16,
    SignedInt64AsBase10,
    AttributionReportingFilterDataEntry,
    AttributionReportingFilterConfig,
    AttributionReportingFilterPair,
    AttributionReportingAggregationKeysEntry,
    AttributionReportingEventReportWindows,
    AttributionReportingTriggerDataMatching,
    AttributionReportingAggregatableDebugReportingData,
    AttributionReportingAggregatableDebugReportingConfig,
    AttributionScopesData,
    AttributionReportingNamedBudgetDef,
    AttributionReportingSourceRegistration,
    AttributionReportingSourceRegistrationResult,
    AttributionReportingSourceRegistrationTimeConfig,
    AttributionReportingAggregatableValueDictEntry,
    AttributionReportingAggregatableValueEntry,
    AttributionReportingEventTriggerData,
    AttributionReportingAggregatableTriggerData,
    AttributionReportingAggregatableDedupKey,
    AttributionReportingNamedBudgetCandidate,
    AttributionReportingTriggerRegistration,
    AttributionReportingEventLevelResult,
    AttributionReportingAggregatableResult,
    AttributionReportingReportResult,
    RelatedWebsiteSet,
    CacheStorageContentUpdated,
    CacheStorageListUpdated,
    IndexedDBContentUpdated,
    IndexedDBListUpdated,
    InterestGroupAccessed,
    InterestGroupAuctionEventOccurred,
    InterestGroupAuctionNetworkRequestCreated,
    SharedStorageAccessed,
    SharedStorageWorkletOperationExecutionFinished,
    StorageBucketCreatedOrUpdated,
    StorageBucketDeleted,
    AttributionReportingSourceRegistered,
    AttributionReportingTriggerRegistered,
    AttributionReportingReportSent,
    AttributionReportingVerboseDebugReportSent,
    GetStorageKeyForFrame,
    GetStorageKey,
    ClearDataForOrigin,
    ClearDataForStorageKey,
    GetCookies,
    SetCookies,
    ClearCookies,
    GetUsageAndQuota,
    OverrideQuotaForOrigin,
    TrackCacheStorageForOrigin,
    TrackCacheStorageForStorageKey,
    TrackIndexedDBForOrigin,
    TrackIndexedDBForStorageKey,
    UntrackCacheStorageForOrigin,
    UntrackCacheStorageForStorageKey,
    UntrackIndexedDBForOrigin,
    UntrackIndexedDBForStorageKey,
    GetTrustTokens,
    ClearTrustTokens,
    GetInterestGroupDetails,
    SetInterestGroupTracking,
    SetInterestGroupAuctionTracking,
    GetSharedStorageMetadata,
    GetSharedStorageEntries,
    SetSharedStorageEntry,
    DeleteSharedStorageEntry,
    ClearSharedStorageEntries,
    ResetSharedStorageBudget,
    SetSharedStorageTracking,
    SetStorageBucketTracking,
    DeleteStorageBucket,
    RunBounceTrackingMitigations,
    SetAttributionReportingLocalTestingMode,
    SetAttributionReportingTracking,
    SendPendingAttributionReports,
    GetRelatedWebsiteSets,
    GetAffectedUrlsForThirdPartyCookieMetadata,
    SetProtectedAudienceKAnonymity,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Storage/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Browser,
    Network,
    Page,
    Storage,
)
from cdpkit.protocol.base import JSON_DICT, CDPMethod, InputModel, OutputModel


class GetStorageKeyForFrameInput(InputModel):

    frameId: Page.FrameId


class GetStorageKeyForFrameOutput(OutputModel):

    storageKey: Storage.SerializedStorageKey


class GetStorageKeyForFrame(CDPMethod[GetStorageKeyForFrameOutput]):  # deprecated
    """ Returns a storage key given a frame id.
    Deprecated. Please use Storage.getStorageKey instead. """

    INPUT_VALIDATOR = GetStorageKeyForFrameInput
    OUTPUT_VALIDATOR = GetStorageKeyForFrameOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId
    ):
        super().__init__(
            frameId=frame_id
        )


class GetStorageKeyInput(InputModel):

    frameId: Page.FrameId | None = None


class GetStorageKeyOutput(OutputModel):

    storageKey: Storage.SerializedStorageKey


class GetStorageKey(CDPMethod[GetStorageKeyOutput]):  # experimental
    """ Returns storage key for the given frame. If no frame ID is provided,
    the storage key of the target executing this command is returned. """

    INPUT_VALIDATOR = GetStorageKeyInput
    OUTPUT_VALIDATOR = GetStorageKeyOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId | None = None
    ):
        super().__init__(
            frameId=frame_id
        )


class ClearDataForOriginInput(InputModel):

    origin: str
    storageTypes: str


class ClearDataForOrigin(CDPMethod[None]):
    """ Clears storage for origin. """

    INPUT_VALIDATOR = ClearDataForOriginInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        origin: str,
        storage_types: str
    ):
        super().__init__(
            origin=origin,
            storageTypes=storage_types
        )


class ClearDataForStorageKeyInput(InputModel):

    storageKey: str
    storageTypes: str


class ClearDataForStorageKey(CDPMethod[None]):
    """ Clears storage for storage key. """

    INPUT_VALIDATOR = ClearDataForStorageKeyInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        storage_key: str,
        storage_types: str
    ):
        super().__init__(
            storageKey=storage_key,
            storageTypes=storage_types
        )


class GetCookiesInput(InputModel):

    browserContextId: Browser.BrowserContextID | None = None


class GetCookiesOutput(OutputModel):

    cookies: list[Network.Cookie]


class GetCookies(CDPMethod[GetCookiesOutput]):
    """ Returns all browser cookies. """

    INPUT_VALIDATOR = GetCookiesInput
    OUTPUT_VALIDATOR = GetCookiesOutput

    def __init__(
        self,
        *,
        browser_context_id: Browser.BrowserContextID | None = None
    ):
        super().__init__(
            browserContextId=browser_context_id
        )


class SetCookiesInput(InputModel):

    cookies: list[Network.CookieParam]
    browserContextId: Browser.BrowserContextID | None = None


class SetCookies(CDPMethod[None]):
    """ Sets given cookies. """

    INPUT_VALIDATOR = SetCookiesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        cookies: list[Network.CookieParam],
        browser_context_id: Browser.BrowserContextID | None = None
    ):
        super().__init__(
            cookies=cookies,
            browserContextId=browser_context_id
        )


class ClearCookiesInput(InputModel):

    browserContextId: Browser.BrowserContextID | None = None


class ClearCookies(CDPMethod[None]):
    """ Clears cookies. """

    INPUT_VALIDATOR = ClearCookiesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        browser_context_id: Browser.BrowserContextID | None = None
    ):
        super().__init__(
            browserContextId=browser_context_id
        )


class GetUsageAndQuotaInput(InputModel):

    origin: str


class GetUsageAndQuotaOutput(OutputModel):

    usage: float
    quota: float
    overrideActive: bool
    usageBreakdown: list[Storage.UsageForType]


class GetUsageAndQuota(CDPMethod[GetUsageAndQuotaOutput]):
    """ Returns usage and quota in bytes. """

    INPUT_VALIDATOR = GetUsageAndQuotaInput
    OUTPUT_VALIDATOR = GetUsageAndQuotaOutput

    def __init__(
        self,
        *,
        origin: str
    ):
        super().__init__(
            origin=origin
        )


class OverrideQuotaForOriginInput(InputModel):

    origin: str
    quotaSize: float | None = None


class OverrideQuotaForOrigin(CDPMethod[None]):  # experimental
    """ Override quota for the specified origin """

    INPUT_VALIDATOR = OverrideQuotaForOriginInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        origin: str,
        quota_size: float | None = None
    ):
        super().__init__(
            origin=origin,
            quotaSize=quota_size
        )


class TrackCacheStorageForOriginInput(InputModel):

    origin: str


class TrackCacheStorageForOrigin(CDPMethod[None]):
    """ Registers origin to be notified when an update occurs to its cache storage list. """

    INPUT_VALIDATOR = TrackCacheStorageForOriginInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        origin: str
    ):
        super().__init__(
            origin=origin
        )


class TrackCacheStorageForStorageKeyInput(InputModel):

    storageKey: str


class TrackCacheStorageForStorageKey(CDPMethod[None]):
    """ Registers storage key to be notified when an update occurs to its cache storage list. """

    INPUT_VALIDATOR = TrackCacheStorageForStorageKeyInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        storage_key: str
    ):
        super().__init__(
            storageKey=storage_key
        )


class TrackIndexedDBForOriginInput(InputModel):

    origin: str


class TrackIndexedDBForOrigin(CDPMethod[None]):
    """ Registers origin to be notified when an update occurs to its IndexedDB. """

    INPUT_VALIDATOR = TrackIndexedDBForOriginInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        origin: str
    ):
        super().__init__(
            origin=origin
        )


class TrackIndexedDBForStorageKeyInput(InputModel):

    storageKey: str


class TrackIndexedDBForStorageKey(CDPMethod[None]):
    """ Registers storage key to be notified when an update occurs to its IndexedDB. """

    INPUT_VALIDATOR = TrackIndexedDBForStorageKeyInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        storage_key: str
    ):
        super().__init__(
            storageKey=storage_key
        )


class UntrackCacheStorageForOriginInput(InputModel):

    origin: str


class UntrackCacheStorageForOrigin(CDPMethod[None]):
    """ Unregisters origin from receiving notifications for cache storage. """

    INPUT_VALIDATOR = UntrackCacheStorageForOriginInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        origin: str
    ):
        super().__init__(
            origin=origin
        )


class UntrackCacheStorageForStorageKeyInput(InputModel):

    storageKey: str


class UntrackCacheStorageForStorageKey(CDPMethod[None]):
    """ Unregisters storage key from receiving notifications for cache storage. """

    INPUT_VALIDATOR = UntrackCacheStorageForStorageKeyInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        storage_key: str
    ):
        super().__init__(
            storageKey=storage_key
        )


class UntrackIndexedDBForOriginInput(InputModel):

    origin: str


class UntrackIndexedDBForOrigin(CDPMethod[None]):
    """ Unregisters origin from receiving notifications for IndexedDB. """

    INPUT_VALIDATOR = UntrackIndexedDBForOriginInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        origin: str
    ):
        super().__init__(
            origin=origin
        )


class UntrackIndexedDBForStorageKeyInput(InputModel):

    storageKey: str


class UntrackIndexedDBForStorageKey(CDPMethod[None]):
    """ Unregisters storage key from receiving notifications for IndexedDB. """

    INPUT_VALIDATOR = UntrackIndexedDBForStorageKeyInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        storage_key: str
    ):
        super().__init__(
            storageKey=storage_key
        )


class GetTrustTokensOutput(OutputModel):

    tokens: list[Storage.TrustTokens]


class GetTrustTokens(CDPMethod[GetTrustTokensOutput]):  # experimental
    """ Returns the number of stored Trust Tokens per issuer for the
    current browsing context. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetTrustTokensOutput


class ClearTrustTokensInput(InputModel):

    issuerOrigin: str


class ClearTrustTokensOutput(OutputModel):

    didDeleteTokens: bool


class ClearTrustTokens(CDPMethod[ClearTrustTokensOutput]):  # experimental
    """ Removes all Trust Tokens issued by the provided issuerOrigin.
    Leaves other stored data, including the issuer's Redemption Records, intact. """

    INPUT_VALIDATOR = ClearTrustTokensInput
    OUTPUT_VALIDATOR = ClearTrustTokensOutput

    def __init__(
        self,
        *,
        issuer_origin: str
    ):
        super().__init__(
            issuerOrigin=issuer_origin
        )


class GetInterestGroupDetailsInput(InputModel):

    ownerOrigin: str
    name: str


class GetInterestGroupDetailsOutput(OutputModel):

    details: JSON_DICT


class GetInterestGroupDetails(CDPMethod[GetInterestGroupDetailsOutput]):  # experimental
    """ Gets details for a named interest group. """

    INPUT_VALIDATOR = GetInterestGroupDetailsInput
    OUTPUT_VALIDATOR = GetInterestGroupDetailsOutput

    def __init__(
        self,
        *,
        owner_origin: str,
        name: str
    ):
        super().__init__(
            ownerOrigin=owner_origin,
            name=name
        )


class SetInterestGroupTrackingInput(InputModel):

    enable: bool


class SetInterestGroupTracking(CDPMethod[None]):  # experimental
    """ Enables/Disables issuing of interestGroupAccessed events. """

    INPUT_VALIDATOR = SetInterestGroupTrackingInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enable: bool
    ):
        super().__init__(
            enable=enable
        )


class SetInterestGroupAuctionTrackingInput(InputModel):

    enable: bool


class SetInterestGroupAuctionTracking(CDPMethod[None]):  # experimental
    """ Enables/Disables issuing of interestGroupAuctionEventOccurred and
    interestGroupAuctionNetworkRequestCreated. """

    INPUT_VALIDATOR = SetInterestGroupAuctionTrackingInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enable: bool
    ):
        super().__init__(
            enable=enable
        )


class GetSharedStorageMetadataInput(InputModel):

    ownerOrigin: str


class GetSharedStorageMetadataOutput(OutputModel):

    metadata: Storage.SharedStorageMetadata


class GetSharedStorageMetadata(CDPMethod[GetSharedStorageMetadataOutput]):  # experimental
    """ Gets metadata for an origin's shared storage. """

    INPUT_VALIDATOR = GetSharedStorageMetadataInput
    OUTPUT_VALIDATOR = GetSharedStorageMetadataOutput

    def __init__(
        self,
        *,
        owner_origin: str
    ):
        super().__init__(
            ownerOrigin=owner_origin
        )


class GetSharedStorageEntriesInput(InputModel):

    ownerOrigin: str


class GetSharedStorageEntriesOutput(OutputModel):

    entries: list[Storage.SharedStorageEntry]


class GetSharedStorageEntries(CDPMethod[GetSharedStorageEntriesOutput]):  # experimental
    """ Gets the entries in an given origin's shared storage. """

    INPUT_VALIDATOR = GetSharedStorageEntriesInput
    OUTPUT_VALIDATOR = GetSharedStorageEntriesOutput

    def __init__(
        self,
        *,
        owner_origin: str
    ):
        super().__init__(
            ownerOrigin=owner_origin
        )


class SetSharedStorageEntryInput(InputModel):

    ownerOrigin: str
    key: str
    value: str
    ignoreIfPresent: bool | None = None


class SetSharedStorageEntry(CDPMethod[None]):  # experimental
    """ Sets entry with `key` and `value` for a given origin's shared storage. """

    INPUT_VALIDATOR = SetSharedStorageEntryInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        owner_origin: str,
        key: str,
        value: str,
        ignore_if_present: bool | None = None
    ):
        super().__init__(
            ownerOrigin=owner_origin,
            key=key,
            value=value,
            ignoreIfPresent=ignore_if_present
        )


class DeleteSharedStorageEntryInput(InputModel):

    ownerOrigin: str
    key: str


class DeleteSharedStorageEntry(CDPMethod[None]):  # experimental
    """ Deletes entry for `key` (if it exists) for a given origin's shared storage. """

    INPUT_VALIDATOR = DeleteSharedStorageEntryInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        owner_origin: str,
        key: str
    ):
        super().__init__(
            ownerOrigin=owner_origin,
            key=key
        )


class ClearSharedStorageEntriesInput(InputModel):

    ownerOrigin: str


class ClearSharedStorageEntries(CDPMethod[None]):  # experimental
    """ Clears all entries for a given origin's shared storage. """

    INPUT_VALIDATOR = ClearSharedStorageEntriesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        owner_origin: str
    ):
        super().__init__(
            ownerOrigin=owner_origin
        )


class ResetSharedStorageBudgetInput(InputModel):

    ownerOrigin: str


class ResetSharedStorageBudget(CDPMethod[None]):  # experimental
    """ Resets the budget for `ownerOrigin` by clearing all budget withdrawals. """

    INPUT_VALIDATOR = ResetSharedStorageBudgetInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        owner_origin: str
    ):
        super().__init__(
            ownerOrigin=owner_origin
        )


class SetSharedStorageTrackingInput(InputModel):

    enable: bool


class SetSharedStorageTracking(CDPMethod[None]):  # experimental
    """ Enables/disables issuing of sharedStorageAccessed events. """

    INPUT_VALIDATOR = SetSharedStorageTrackingInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enable: bool
    ):
        super().__init__(
            enable=enable
        )


class SetStorageBucketTrackingInput(InputModel):

    storageKey: str
    enable: bool


class SetStorageBucketTracking(CDPMethod[None]):  # experimental
    """ Set tracking for a storage key's buckets. """

    INPUT_VALIDATOR = SetStorageBucketTrackingInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        storage_key: str,
        enable: bool
    ):
        super().__init__(
            storageKey=storage_key,
            enable=enable
        )


class DeleteStorageBucketInput(InputModel):

    bucket: Storage.StorageBucket


class DeleteStorageBucket(CDPMethod[None]):  # experimental
    """ Deletes the Storage Bucket with the given storage key and bucket name. """

    INPUT_VALIDATOR = DeleteStorageBucketInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        bucket: Storage.StorageBucket
    ):
        super().__init__(
            bucket=bucket
        )


class RunBounceTrackingMitigationsOutput(OutputModel):

    deletedSites: list[str]


class RunBounceTrackingMitigations(CDPMethod[RunBounceTrackingMitigationsOutput]):  # experimental
    """ Deletes state for sites identified as potential bounce trackers, immediately. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = RunBounceTrackingMitigationsOutput


class SetAttributionReportingLocalTestingModeInput(InputModel):

    enabled: bool


class SetAttributionReportingLocalTestingMode(CDPMethod[None]):  # experimental
    """ https://wicg.github.io/attribution-reporting-api/ """

    INPUT_VALIDATOR = SetAttributionReportingLocalTestingModeInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool
    ):
        super().__init__(
            enabled=enabled
        )


class SetAttributionReportingTrackingInput(InputModel):

    enable: bool


class SetAttributionReportingTracking(CDPMethod[None]):  # experimental
    """ Enables/disables issuing of Attribution Reporting events. """

    INPUT_VALIDATOR = SetAttributionReportingTrackingInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enable: bool
    ):
        super().__init__(
            enable=enable
        )


class SendPendingAttributionReportsOutput(OutputModel):

    numSent: int


class SendPendingAttributionReports(CDPMethod[SendPendingAttributionReportsOutput]):  # experimental
    """ Sends all pending Attribution Reports immediately, regardless of their
    scheduled report time. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = SendPendingAttributionReportsOutput


class GetRelatedWebsiteSetsOutput(OutputModel):

    sets: list[Storage.RelatedWebsiteSet]


class GetRelatedWebsiteSets(CDPMethod[GetRelatedWebsiteSetsOutput]):  # experimental
    """ Returns the effective Related Website Sets in use by this profile for the browser
    session. The effective Related Website Sets will not change during a browser session. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetRelatedWebsiteSetsOutput


class GetAffectedUrlsForThirdPartyCookieMetadataInput(InputModel):

    firstPartyUrl: str
    thirdPartyUrls: list[str]


class GetAffectedUrlsForThirdPartyCookieMetadataOutput(OutputModel):

    matchedUrls: list[str]


class GetAffectedUrlsForThirdPartyCookieMetadata(CDPMethod[GetAffectedUrlsForThirdPartyCookieMetadataOutput]):  # experimental
    """ Returns the list of URLs from a page and its embedded resources that match
    existing grace period URL pattern rules.
    https://developers.google.com/privacy-sandbox/cookies/temporary-exceptions/grace-period """

    INPUT_VALIDATOR = GetAffectedUrlsForThirdPartyCookieMetadataInput
    OUTPUT_VALIDATOR = GetAffectedUrlsForThirdPartyCookieMetadataOutput

    def __init__(
        self,
        *,
        first_party_url: str,
        third_party_urls: list[str]
    ):
        super().__init__(
            firstPartyUrl=first_party_url,
            thirdPartyUrls=third_party_urls
        )


class SetProtectedAudienceKAnonymityInput(InputModel):

    owner: str
    name: str
    hashes: list[str]


class SetProtectedAudienceKAnonymity(CDPMethod[None]):

    INPUT_VALIDATOR = SetProtectedAudienceKAnonymityInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        owner: str,
        name: str,
        hashes: list[str]
    ):
        super().__init__(
            owner=owner,
            name=name,
            hashes=hashes
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain provides various functionality related to drawing atop the inspected page.
https://chromedevtools.github.io/devtools-protocol/tot/Overlay/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOM,
    Page,
)
from cdpkit.protocol.base import CDPEvent


class InspectNodeRequested(CDPEvent):
    """ Fired when the node should be inspected. This happens after call to `setInspectMode` or when
    user manually inspects an element. """

    backendNodeId: DOM.BackendNodeId


class NodeHighlightRequested(CDPEvent):
    """ Fired when the node should be highlighted. This happens after call to `setInspectMode`. """

    nodeId: DOM.NodeId


class ScreenshotRequested(CDPEvent):
    """ Fired when user asks to capture screenshot of some area on the page. """

    viewport: Page.Viewport


class InspectModeCanceled(CDPEvent):
    """ Fired when user cancels the inspect mode. """

    ...



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing
breakpoints, stepping through execution, exploring stack traces, etc.
https://chromedevtools.github.io/devtools-protocol/tot/Debugger/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    Debugger,
    Runtime,
)
from cdpkit.protocol.base import JSON_DICT, CDPEvent


class BreakpointResolved(CDPEvent):
    """ Fired when breakpoint is resolved to an actual script and location.
    Deprecated in favor of `resolvedBreakpoints` in the `scriptParsed` event. """

    breakpointId: Debugger.BreakpointId
    location: Debugger.Location


class Paused(CDPEvent):
    """ Fired when the virtual machine stopped on breakpoint or exception or any other stop criteria. """

    callFrames: list[Debugger.CallFrame]
    reason: Literal['ambiguous', 'assert', 'CSPViolation', 'debugCommand', 'DOM', 'EventListener', 'exception', 'instrumentation', 'OOM', 'other', 'promiseRejection', 'XHR', 'step']
    data: JSON_DICT | None = None
    hitBreakpoints: list[str] | None = None
    asyncStackTrace: Runtime.StackTrace | None = None
    asyncStackTraceId: Runtime.StackTraceId | None = None  # experimental
    asyncCallStackTraceId: Runtime.StackTraceId | None = None  # experimental deprecated


class Resumed(CDPEvent):
    """ Fired when the virtual machine resumed execution. """

    ...


class ScriptFailedToParse(CDPEvent):
    """ Fired when virtual machine fails to parse the script. """

    scriptId: Runtime.ScriptId
    url: str
    startLine: int
    startColumn: int
    endLine: int
    endColumn: int
    executionContextId: Runtime.ExecutionContextId
    hash: str
    buildId: str
    executionContextAuxData: JSON_DICT | None = None
    sourceMapURL: str | None = None
    hasSourceURL: bool | None = None
    isModule: bool | None = None
    length: int | None = None
    stackTrace: Runtime.StackTrace | None = None  # experimental
    codeOffset: int | None = None  # experimental
    scriptLanguage: Debugger.ScriptLanguage | None = None  # experimental
    embedderName: str | None = None  # experimental


class ScriptParsed(CDPEvent):
    """ Fired when virtual machine parses script. This event is also fired for all known and uncollected
    scripts upon enabling debugger. """

    scriptId: Runtime.ScriptId
    url: str
    startLine: int
    startColumn: int
    endLine: int
    endColumn: int
    executionContextId: Runtime.ExecutionContextId
    hash: str
    buildId: str
    executionContextAuxData: JSON_DICT | None = None
    isLiveEdit: bool | None = None  # experimental
    sourceMapURL: str | None = None
    hasSourceURL: bool | None = None
    isModule: bool | None = None
    length: int | None = None
    stackTrace: Runtime.StackTrace | None = None  # experimental
    codeOffset: int | None = None  # experimental
    scriptLanguage: Debugger.ScriptLanguage | None = None  # experimental
    debugSymbols: list[Debugger.DebugSymbols] | None = None  # experimental
    embedderName: str | None = None  # experimental
    resolvedBreakpoints: list[Debugger.ResolvedBreakpoint] | None = None  # experimental



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Runtime domain exposes JavaScript runtime by means of remote evaluation and mirror objects.
Evaluation results are returned as mirror object that expose object type, string representation
and unique identifier that can be used for further object reference. Original objects are
maintained in memory unless they are either explicitly released or are released along with the
other objects in their object group.
https://chromedevtools.github.io/devtools-protocol/tot/Runtime/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    RuntimeCallArgument,
    RuntimeCallFrame,
    RuntimeCustomPreview,
    RuntimeDeepSerializedValue,
    RuntimeEntryPreview,
    RuntimeExceptionDetails,
    RuntimeExecutionContextDescription,
    RuntimeExecutionContextId,
    RuntimeInternalPropertyDescriptor,
    RuntimeObjectPreview,
    RuntimePrivatePropertyDescriptor,
    RuntimePropertyDescriptor,
    RuntimePropertyPreview,
    RuntimeRemoteObject,
    RuntimeRemoteObjectId,
    RuntimeScriptId,
    RuntimeSerializationOptions,
    RuntimeStackTrace,
    RuntimeStackTraceId,
    RuntimeTimeDelta,
    RuntimeTimestamp,
    RuntimeUniqueDebuggerId,
    RuntimeUnserializableValue,
)

ScriptId = RuntimeScriptId
SerializationOptions = RuntimeSerializationOptions
DeepSerializedValue = RuntimeDeepSerializedValue
RemoteObjectId = RuntimeRemoteObjectId
UnserializableValue = RuntimeUnserializableValue
RemoteObject = RuntimeRemoteObject
CustomPreview = RuntimeCustomPreview
ObjectPreview = RuntimeObjectPreview
PropertyPreview = RuntimePropertyPreview
EntryPreview = RuntimeEntryPreview
PropertyDescriptor = RuntimePropertyDescriptor
InternalPropertyDescriptor = RuntimeInternalPropertyDescriptor
PrivatePropertyDescriptor = RuntimePrivatePropertyDescriptor
CallArgument = RuntimeCallArgument
ExecutionContextId = RuntimeExecutionContextId
ExecutionContextDescription = RuntimeExecutionContextDescription
ExceptionDetails = RuntimeExceptionDetails
Timestamp = RuntimeTimestamp
TimeDelta = RuntimeTimeDelta
CallFrame = RuntimeCallFrame
StackTrace = RuntimeStackTrace
UniqueDebuggerId = RuntimeUniqueDebuggerId
StackTraceId = RuntimeStackTraceId



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

A domain for interacting with Cast, Presentation API, and Remote Playback API
functionalities.
https://chromedevtools.github.io/devtools-protocol/tot/Cast/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Cast,
)
from cdpkit.protocol.base import CDPEvent


class SinksUpdated(CDPEvent):
    """ This is fired whenever the list of available sinks changes. A sink is a
    device or a software surface that you can cast to. """

    sinks: list[Cast.Sink]


class IssueUpdated(CDPEvent):
    """ This is fired whenever the outstanding issue/error message changes.
    |issueMessage| is empty if there is no issue. """

    issueMessage: str



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Audits domain allows investigation of page violations and possible improvements.
https://chromedevtools.github.io/devtools-protocol/tot/Audits/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    Audits,
    Network,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class GetEncodedResponseInput(InputModel):

    requestId: Network.RequestId
    encoding: Literal['webp', 'jpeg', 'png']
    quality: float | None = None
    sizeOnly: bool | None = None


class GetEncodedResponseOutput(OutputModel):

    body: str | None = None
    originalSize: int
    encodedSize: int


class GetEncodedResponse(CDPMethod[GetEncodedResponseOutput]):
    """ Returns the response body and size if it were re-encoded with the specified settings. Only
    applies to images. """

    INPUT_VALIDATOR = GetEncodedResponseInput
    OUTPUT_VALIDATOR = GetEncodedResponseOutput

    def __init__(
        self,
        *,
        request_id: Network.RequestId,
        encoding: Literal['webp', 'jpeg', 'png'],
        quality: float | None = None,
        size_only: bool | None = None
    ):
        super().__init__(
            requestId=request_id,
            encoding=encoding,
            quality=quality,
            sizeOnly=size_only
        )


class Disable(CDPMethod[None]):
    """ Disables issues domain, prevents further issues from being reported to the client. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Enable(CDPMethod[None]):
    """ Enables issues domain, sends the issues collected so far to the client by means of the
    `issueAdded` event. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class CheckContrastInput(InputModel):

    reportAAA: bool | None = None


class CheckContrast(CDPMethod[None]):
    """ Runs the contrast check for the target page. Found issues are reported
    using Audits.issueAdded event. """

    INPUT_VALIDATOR = CheckContrastInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        report_aaa: bool | None = None
    ):
        super().__init__(
            reportAAA=report_aaa
        )


class CheckFormsIssuesOutput(OutputModel):

    formIssues: list[Audits.GenericIssueDetails]


class CheckFormsIssues(CDPMethod[CheckFormsIssuesOutput]):
    """ Runs the form issues check for the target page. Found issues are reported
    using Audits.issueAdded event. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = CheckFormsIssuesOutput



from .events import CharacteristicOperationReceived, DescriptorOperationReceived, GattOperationReceived
from .methods import (
    AddCharacteristic,
    AddDescriptor,
    AddService,
    Disable,
    Enable,
    RemoveCharacteristic,
    RemoveDescriptor,
    RemoveService,
    SetSimulatedCentralState,
    SimulateAdvertisement,
    SimulateCharacteristicOperationResponse,
    SimulateDescriptorOperationResponse,
    SimulateGATTDisconnection,
    SimulateGATTOperationResponse,
    SimulatePreconnectedPeripheral,
)
from .types import (
    CentralState,
    CharacteristicOperationType,
    CharacteristicProperties,
    CharacteristicWriteType,
    DescriptorOperationType,
    GATTOperationType,
    ManufacturerData,
    ScanEntry,
    ScanRecord,
)

__all__ = [
    CentralState,
    GATTOperationType,
    CharacteristicWriteType,
    CharacteristicOperationType,
    DescriptorOperationType,
    ManufacturerData,
    ScanRecord,
    ScanEntry,
    CharacteristicProperties,
    GattOperationReceived,
    CharacteristicOperationReceived,
    DescriptorOperationReceived,
    Enable,
    SetSimulatedCentralState,
    Disable,
    SimulatePreconnectedPeripheral,
    SimulateAdvertisement,
    SimulateGATTOperationResponse,
    SimulateCharacteristicOperationResponse,
    SimulateDescriptorOperationResponse,
    AddService,
    RemoveService,
    AddCharacteristic,
    RemoveCharacteristic,
    AddDescriptor,
    RemoveDescriptor,
    SimulateGATTDisconnection,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Defines events for background web platform features.
https://chromedevtools.github.io/devtools-protocol/tot/BackgroundService/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    BackgroundService,
)
from cdpkit.protocol.base import CDPMethod, InputModel


class StartObservingInput(InputModel):

    service: BackgroundService.ServiceName


class StartObserving(CDPMethod[None]):
    """ Enables event updates for the service. """

    INPUT_VALIDATOR = StartObservingInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        service: BackgroundService.ServiceName
    ):
        super().__init__(
            service=service
        )


class StopObservingInput(InputModel):

    service: BackgroundService.ServiceName


class StopObserving(CDPMethod[None]):
    """ Disables event updates for the service. """

    INPUT_VALIDATOR = StopObservingInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        service: BackgroundService.ServiceName
    ):
        super().__init__(
            service=service
        )


class SetRecordingInput(InputModel):

    shouldRecord: bool
    service: BackgroundService.ServiceName


class SetRecording(CDPMethod[None]):
    """ Set the recording state for the service. """

    INPUT_VALIDATOR = SetRecordingInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        should_record: bool,
        service: BackgroundService.ServiceName
    ):
        super().__init__(
            shouldRecord=should_record,
            service=service
        )


class ClearEventsInput(InputModel):

    service: BackgroundService.ServiceName


class ClearEvents(CDPMethod[None]):
    """ Clears all stored data for the service. """

    INPUT_VALIDATOR = ClearEventsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        service: BackgroundService.ServiceName
    ):
        super().__init__(
            service=service
        )



from .events import DomStorageItemAdded, DomStorageItemRemoved, DomStorageItemsCleared, DomStorageItemUpdated
from .methods import Clear, Disable, Enable, GetDOMStorageItems, RemoveDOMStorageItem, SetDOMStorageItem
from .types import Item, SerializedStorageKey, StorageId

__all__ = [
    SerializedStorageKey,
    StorageId,
    Item,
    DomStorageItemAdded,
    DomStorageItemRemoved,
    DomStorageItemUpdated,
    DomStorageItemsCleared,
    Clear,
    Disable,
    Enable,
    GetDOMStorageItems,
    RemoveDOMStorageItem,
    SetDOMStorageItem,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Preload/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Network,
    Page,
    Preload,
)
from cdpkit.protocol.base import CDPEvent


class RuleSetUpdated(CDPEvent):
    """ Upsert. Currently, it is only emitted when a rule set added. """

    ruleSet: Preload.RuleSet


class RuleSetRemoved(CDPEvent):

    id: Preload.RuleSetId


class PreloadEnabledStateUpdated(CDPEvent):
    """ Fired when a preload enabled state is updated. """

    disabledByPreference: bool
    disabledByDataSaver: bool
    disabledByBatterySaver: bool
    disabledByHoldbackPrefetchSpeculationRules: bool
    disabledByHoldbackPrerenderSpeculationRules: bool


class PrefetchStatusUpdated(CDPEvent):
    """ Fired when a prefetch attempt is updated. """

    key: Preload.PreloadingAttemptKey
    pipelineId: Preload.PreloadPipelineId
    initiatingFrameId: Page.FrameId
    prefetchUrl: str
    status: Preload.PreloadingStatus
    prefetchStatus: Preload.PrefetchStatus
    requestId: Network.RequestId


class PrerenderStatusUpdated(CDPEvent):
    """ Fired when a prerender attempt is updated. """

    key: Preload.PreloadingAttemptKey
    pipelineId: Preload.PreloadPipelineId
    status: Preload.PreloadingStatus
    prerenderStatus: Preload.PrerenderFinalStatus | None = None
    disallowedMojoInterface: str | None = None
    mismatchedHeaders: list[Preload.PrerenderMismatchedHeaders] | None = None


class PreloadingAttemptSourcesUpdated(CDPEvent):
    """ Send a list of sources for all preloading attempts in a document. """

    loaderId: Network.LoaderId
    preloadingAttemptSources: list[Preload.PreloadingAttemptSource]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Supports additional targets discovery and allows to attach to them.
https://chromedevtools.github.io/devtools-protocol/tot/Target/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Browser,
    Target,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class ActivateTargetInput(InputModel):

    targetId: Target.TargetID


class ActivateTarget(CDPMethod[None]):
    """ Activates (focuses) the target. """

    INPUT_VALIDATOR = ActivateTargetInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        target_id: Target.TargetID
    ):
        super().__init__(
            targetId=target_id
        )


class AttachToTargetInput(InputModel):

    targetId: Target.TargetID
    flatten: bool | None = None


class AttachToTargetOutput(OutputModel):

    sessionId: Target.SessionID


class AttachToTarget(CDPMethod[AttachToTargetOutput]):
    """ Attaches to the target with given id. """

    INPUT_VALIDATOR = AttachToTargetInput
    OUTPUT_VALIDATOR = AttachToTargetOutput

    def __init__(
        self,
        *,
        target_id: Target.TargetID,
        flatten: bool | None = None
    ):
        super().__init__(
            targetId=target_id,
            flatten=flatten
        )


class AttachToBrowserTargetOutput(OutputModel):

    sessionId: Target.SessionID


class AttachToBrowserTarget(CDPMethod[AttachToBrowserTargetOutput]):  # experimental
    """ Attaches to the browser target, only uses flat sessionId mode. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = AttachToBrowserTargetOutput


class CloseTargetInput(InputModel):

    targetId: Target.TargetID


class CloseTargetOutput(OutputModel):

    success: bool  # deprecated


class CloseTarget(CDPMethod[CloseTargetOutput]):
    """ Closes the target. If the target is a page that gets closed too. """

    INPUT_VALIDATOR = CloseTargetInput
    OUTPUT_VALIDATOR = CloseTargetOutput

    def __init__(
        self,
        *,
        target_id: Target.TargetID
    ):
        super().__init__(
            targetId=target_id
        )


class ExposeDevToolsProtocolInput(InputModel):

    targetId: Target.TargetID
    bindingName: str | None = None
    inheritPermissions: bool | None = None


class ExposeDevToolsProtocol(CDPMethod[None]):  # experimental
    """ Inject object to the target's main frame that provides a communication
    channel with browser target.

    Injected object will be available as `window[bindingName]`.

    The object has the following API:
    - `binding.send(json)` - a method to send messages over the remote debugging protocol
    - `binding.onmessage = json => handleMessage(json)` - a callback that will be called for the protocol notifications and command responses. """

    INPUT_VALIDATOR = ExposeDevToolsProtocolInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        target_id: Target.TargetID,
        binding_name: str | None = None,
        inherit_permissions: bool | None = None
    ):
        super().__init__(
            targetId=target_id,
            bindingName=binding_name,
            inheritPermissions=inherit_permissions
        )


class CreateBrowserContextInput(InputModel):

    disposeOnDetach: bool | None = None  # experimental
    proxyServer: str | None = None  # experimental
    proxyBypassList: str | None = None  # experimental
    originsWithUniversalNetworkAccess: list[str] | None = None  # experimental


class CreateBrowserContextOutput(OutputModel):

    browserContextId: Browser.BrowserContextID


class CreateBrowserContext(CDPMethod[CreateBrowserContextOutput]):
    """ Creates a new empty BrowserContext. Similar to an incognito profile but you can have more than
    one. """

    INPUT_VALIDATOR = CreateBrowserContextInput
    OUTPUT_VALIDATOR = CreateBrowserContextOutput

    def __init__(
        self,
        *,
        dispose_on_detach: bool | None = None,
        proxy_server: str | None = None,
        proxy_bypass_list: str | None = None,
        origins_with_universal_network_access: list[str] | None = None
    ):
        super().__init__(
            disposeOnDetach=dispose_on_detach,
            proxyServer=proxy_server,
            proxyBypassList=proxy_bypass_list,
            originsWithUniversalNetworkAccess=origins_with_universal_network_access
        )


class GetBrowserContextsOutput(OutputModel):

    browserContextIds: list[Browser.BrowserContextID]
    defaultBrowserContextId: Browser.BrowserContextID | None = None  # experimental


class GetBrowserContexts(CDPMethod[GetBrowserContextsOutput]):
    """ Returns all browser contexts created with `Target.createBrowserContext` method. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetBrowserContextsOutput


class CreateTargetInput(InputModel):

    url: str
    left: int | None = None  # experimental
    top: int | None = None  # experimental
    width: int | None = None
    height: int | None = None
    windowState: Target.WindowState | None = None
    browserContextId: Browser.BrowserContextID | None = None  # experimental
    enableBeginFrameControl: bool | None = None  # experimental
    newWindow: bool | None = None
    background: bool | None = None
    forTab: bool | None = None  # experimental
    hidden: bool | None = None  # experimental


class CreateTargetOutput(OutputModel):

    targetId: Target.TargetID


class CreateTarget(CDPMethod[CreateTargetOutput]):
    """ Creates a new page. """

    INPUT_VALIDATOR = CreateTargetInput
    OUTPUT_VALIDATOR = CreateTargetOutput

    def __init__(
        self,
        *,
        url: str,
        left: int | None = None,
        top: int | None = None,
        width: int | None = None,
        height: int | None = None,
        window_state: Target.WindowState | None = None,
        browser_context_id: Browser.BrowserContextID | None = None,
        enable_begin_frame_control: bool | None = None,
        new_window: bool | None = None,
        background: bool | None = None,
        for_tab: bool | None = None,
        hidden: bool | None = None
    ):
        super().__init__(
            url=url,
            left=left,
            top=top,
            width=width,
            height=height,
            windowState=window_state,
            browserContextId=browser_context_id,
            enableBeginFrameControl=enable_begin_frame_control,
            newWindow=new_window,
            background=background,
            forTab=for_tab,
            hidden=hidden
        )


class DetachFromTargetInput(InputModel):

    sessionId: Target.SessionID | None = None
    targetId: Target.TargetID | None = None  # deprecated


class DetachFromTarget(CDPMethod[None]):
    """ Detaches session with given id. """

    INPUT_VALIDATOR = DetachFromTargetInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        session_id: Target.SessionID | None = None,
        target_id: Target.TargetID | None = None
    ):
        super().__init__(
            sessionId=session_id,
            targetId=target_id
        )


class DisposeBrowserContextInput(InputModel):

    browserContextId: Browser.BrowserContextID


class DisposeBrowserContext(CDPMethod[None]):
    """ Deletes a BrowserContext. All the belonging pages will be closed without calling their
    beforeunload hooks. """

    INPUT_VALIDATOR = DisposeBrowserContextInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        browser_context_id: Browser.BrowserContextID
    ):
        super().__init__(
            browserContextId=browser_context_id
        )


class GetTargetInfoInput(InputModel):

    targetId: Target.TargetID | None = None


class GetTargetInfoOutput(OutputModel):

    targetInfo: Target.TargetInfo


class GetTargetInfo(CDPMethod[GetTargetInfoOutput]):  # experimental
    """ Returns information about a target. """

    INPUT_VALIDATOR = GetTargetInfoInput
    OUTPUT_VALIDATOR = GetTargetInfoOutput

    def __init__(
        self,
        *,
        target_id: Target.TargetID | None = None
    ):
        super().__init__(
            targetId=target_id
        )


class GetTargetsInput(InputModel):

    filter: Target.TargetFilter | None = None  # experimental


class GetTargetsOutput(OutputModel):

    targetInfos: list[Target.TargetInfo]


class GetTargets(CDPMethod[GetTargetsOutput]):
    """ Retrieves a list of available targets. """

    INPUT_VALIDATOR = GetTargetsInput
    OUTPUT_VALIDATOR = GetTargetsOutput

    def __init__(
        self,
        *,
        filter_: Target.TargetFilter | None = None
    ):
        super().__init__(
            filter=filter_
        )


class SendMessageToTargetInput(InputModel):

    message: str
    sessionId: Target.SessionID | None = None
    targetId: Target.TargetID | None = None  # deprecated


class SendMessageToTarget(CDPMethod[None]):  # deprecated
    """ Sends protocol message over session with given id.
    Consider using flat mode instead; see commands attachToTarget, setAutoAttach,
    and crbug.com/991325. """

    INPUT_VALIDATOR = SendMessageToTargetInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        message: str,
        session_id: Target.SessionID | None = None,
        target_id: Target.TargetID | None = None
    ):
        super().__init__(
            message=message,
            sessionId=session_id,
            targetId=target_id
        )


class SetAutoAttachInput(InputModel):

    autoAttach: bool
    waitForDebuggerOnStart: bool
    flatten: bool | None = None  # experimental
    filter: Target.TargetFilter | None = None  # experimental


class SetAutoAttach(CDPMethod[None]):
    """ Controls whether to automatically attach to new targets which are considered
    to be directly related to this one (for example, iframes or workers).
    When turned on, attaches to all existing related targets as well. When turned off,
    automatically detaches from all currently attached targets.
    This also clears all targets added by `autoAttachRelated` from the list of targets to watch
    for creation of related targets.
    You might want to call this recursively for auto-attached targets to attach
    to all available targets. """

    INPUT_VALIDATOR = SetAutoAttachInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        auto_attach: bool,
        wait_for_debugger_on_start: bool,
        flatten: bool | None = None,
        filter_: Target.TargetFilter | None = None
    ):
        super().__init__(
            autoAttach=auto_attach,
            waitForDebuggerOnStart=wait_for_debugger_on_start,
            flatten=flatten,
            filter=filter_
        )


class AutoAttachRelatedInput(InputModel):

    targetId: Target.TargetID
    waitForDebuggerOnStart: bool
    filter: Target.TargetFilter | None = None  # experimental


class AutoAttachRelated(CDPMethod[None]):  # experimental
    """ Adds the specified target to the list of targets that will be monitored for any related target
    creation (such as child frames, child workers and new versions of service worker) and reported
    through `attachedToTarget`. The specified target is also auto-attached.
    This cancels the effect of any previous `setAutoAttach` and is also cancelled by subsequent
    `setAutoAttach`. Only available at the Browser target. """

    INPUT_VALIDATOR = AutoAttachRelatedInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        target_id: Target.TargetID,
        wait_for_debugger_on_start: bool,
        filter_: Target.TargetFilter | None = None
    ):
        super().__init__(
            targetId=target_id,
            waitForDebuggerOnStart=wait_for_debugger_on_start,
            filter=filter_
        )


class SetDiscoverTargetsInput(InputModel):

    discover: bool
    filter: Target.TargetFilter | None = None  # experimental


class SetDiscoverTargets(CDPMethod[None]):
    """ Controls whether to discover available targets and notify via
    `targetCreated/targetInfoChanged/targetDestroyed` events. """

    INPUT_VALIDATOR = SetDiscoverTargetsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        discover: bool,
        filter_: Target.TargetFilter | None = None
    ):
        super().__init__(
            discover=discover,
            filter=filter_
        )


class SetRemoteLocationsInput(InputModel):

    locations: list[Target.RemoteLocation]


class SetRemoteLocations(CDPMethod[None]):  # experimental
    """ Enables target discovery for the specified locations, when `setDiscoverTargets` was set to
    `true`. """

    INPUT_VALIDATOR = SetRemoteLocationsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        locations: list[Target.RemoteLocation]
    ):
        super().__init__(
            locations=locations
        )


class GetDevToolsTargetInput(InputModel):

    targetId: Target.TargetID


class GetDevToolsTargetOutput(OutputModel):

    targetId: Target.TargetID | None = None


class GetDevToolsTarget(CDPMethod[GetDevToolsTargetOutput]):  # experimental
    """ Gets the targetId of the DevTools page target opened for the given target
    (if any). """

    INPUT_VALIDATOR = GetDevToolsTargetInput
    OUTPUT_VALIDATOR = GetDevToolsTargetOutput

    def __init__(
        self,
        *,
        target_id: Target.TargetID
    ):
        super().__init__(
            targetId=target_id
        )


class OpenDevToolsInput(InputModel):

    targetId: Target.TargetID
    panelId: str | None = None


class OpenDevToolsOutput(OutputModel):

    targetId: Target.TargetID


class OpenDevTools(CDPMethod[OpenDevToolsOutput]):  # experimental
    """ Opens a DevTools window for the target. """

    INPUT_VALIDATOR = OpenDevToolsInput
    OUTPUT_VALIDATOR = OpenDevToolsOutput

    def __init__(
        self,
        *,
        target_id: Target.TargetID,
        panel_id: str | None = None
    ):
        super().__init__(
            targetId=target_id,
            panelId=panel_id
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Memory/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Memory,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class GetDOMCountersOutput(OutputModel):

    documents: int
    nodes: int
    jsEventListeners: int


class GetDOMCounters(CDPMethod[GetDOMCountersOutput]):
    """ Retruns current DOM object counters. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetDOMCountersOutput


class GetDOMCountersForLeakDetectionOutput(OutputModel):

    counters: list[Memory.DOMCounter]


class GetDOMCountersForLeakDetection(CDPMethod[GetDOMCountersForLeakDetectionOutput]):
    """ Retruns DOM object counters after preparing renderer for leak detection. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetDOMCountersForLeakDetectionOutput


class PrepareForLeakDetection(CDPMethod[None]):
    """ Prepares for leak detection by terminating workers, stopping spellcheckers,
    dropping non-essential internal caches, running garbage collections, etc. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class ForciblyPurgeJavaScriptMemory(CDPMethod[None]):
    """ Simulate OomIntervention by purging V8 memory. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class SetPressureNotificationsSuppressedInput(InputModel):

    suppressed: bool


class SetPressureNotificationsSuppressed(CDPMethod[None]):
    """ Enable/disable suppressing memory pressure notifications in all processes. """

    INPUT_VALIDATOR = SetPressureNotificationsSuppressedInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        suppressed: bool
    ):
        super().__init__(
            suppressed=suppressed
        )


class SimulatePressureNotificationInput(InputModel):

    level: Memory.PressureLevel


class SimulatePressureNotification(CDPMethod[None]):
    """ Simulate a memory pressure notification in all processes. """

    INPUT_VALIDATOR = SimulatePressureNotificationInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        level: Memory.PressureLevel
    ):
        super().__init__(
            level=level
        )


class StartSamplingInput(InputModel):

    samplingInterval: int | None = None
    suppressRandomness: bool | None = None


class StartSampling(CDPMethod[None]):
    """ Start collecting native memory profile. """

    INPUT_VALIDATOR = StartSamplingInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        sampling_interval: int | None = None,
        suppress_randomness: bool | None = None
    ):
        super().__init__(
            samplingInterval=sampling_interval,
            suppressRandomness=suppress_randomness
        )


class StopSampling(CDPMethod[None]):
    """ Stop collecting native memory profile. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class GetAllTimeSamplingProfileOutput(OutputModel):

    profile: Memory.SamplingProfile


class GetAllTimeSamplingProfile(CDPMethod[GetAllTimeSamplingProfileOutput]):
    """ Retrieve native memory allocations profile
    collected since renderer process startup. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetAllTimeSamplingProfileOutput


class GetBrowserSamplingProfileOutput(OutputModel):

    profile: Memory.SamplingProfile


class GetBrowserSamplingProfile(CDPMethod[GetBrowserSamplingProfileOutput]):
    """ Retrieve native memory allocations profile
    collected since browser process startup. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetBrowserSamplingProfileOutput


class GetSamplingProfileOutput(OutputModel):

    profile: Memory.SamplingProfile


class GetSamplingProfile(CDPMethod[GetSamplingProfileOutput]):
    """ Retrieve native memory allocations profile collected since last
    `startSampling` call. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetSamplingProfileOutput



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Reporting of performance timeline events, as specified in
https://w3c.github.io/performance-timeline/#dom-performanceobserver.
https://chromedevtools.github.io/devtools-protocol/tot/PerformanceTimeline/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    PerformanceTimelineLargestContentfulPaint,
    PerformanceTimelineLayoutShift,
    PerformanceTimelineLayoutShiftAttribution,
    PerformanceTimelineTimelineEvent,
)

LargestContentfulPaint = PerformanceTimelineLargestContentfulPaint
LayoutShiftAttribution = PerformanceTimelineLayoutShiftAttribution
LayoutShift = PerformanceTimelineLayoutShift
TimelineEvent = PerformanceTimelineTimelineEvent



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Tracing/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    Tracing,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class End(CDPMethod[None]):
    """ Stop trace events collection. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class GetCategoriesOutput(OutputModel):

    categories: list[str]


class GetCategories(CDPMethod[GetCategoriesOutput]):  # experimental
    """ Gets supported tracing categories. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetCategoriesOutput


class GetTrackEventDescriptorOutput(OutputModel):

    descriptor: str


class GetTrackEventDescriptor(CDPMethod[GetTrackEventDescriptorOutput]):  # experimental
    """ Return a descriptor for all available tracing categories. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetTrackEventDescriptorOutput


class RecordClockSyncMarkerInput(InputModel):

    syncId: str


class RecordClockSyncMarker(CDPMethod[None]):  # experimental
    """ Record a clock sync marker in the trace. """

    INPUT_VALIDATOR = RecordClockSyncMarkerInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        sync_id: str
    ):
        super().__init__(
            syncId=sync_id
        )


class RequestMemoryDumpInput(InputModel):

    deterministic: bool | None = None
    levelOfDetail: Tracing.MemoryDumpLevelOfDetail | None = None


class RequestMemoryDumpOutput(OutputModel):

    dumpGuid: str
    success: bool


class RequestMemoryDump(CDPMethod[RequestMemoryDumpOutput]):  # experimental
    """ Request a global memory dump. """

    INPUT_VALIDATOR = RequestMemoryDumpInput
    OUTPUT_VALIDATOR = RequestMemoryDumpOutput

    def __init__(
        self,
        *,
        deterministic: bool | None = None,
        level_of_detail: Tracing.MemoryDumpLevelOfDetail | None = None
    ):
        super().__init__(
            deterministic=deterministic,
            levelOfDetail=level_of_detail
        )


class StartInput(InputModel):

    categories: str | None = None  # experimental deprecated
    options: str | None = None  # experimental deprecated
    bufferUsageReportingInterval: float | None = None  # experimental
    transferMode: Literal['ReportEvents', 'ReturnAsStream'] | None = None
    streamFormat: Tracing.StreamFormat | None = None
    streamCompression: Tracing.StreamCompression | None = None  # experimental
    traceConfig: Tracing.TraceConfig | None = None
    perfettoConfig: str | None = None  # experimental
    tracingBackend: Tracing.TracingBackend | None = None  # experimental


class Start(CDPMethod[None]):
    """ Start trace events collection. """

    INPUT_VALIDATOR = StartInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        categories: str | None = None,
        options: str | None = None,
        buffer_usage_reporting_interval: float | None = None,
        transfer_mode: Literal['ReportEvents', 'ReturnAsStream'] | None = None,
        stream_format: Tracing.StreamFormat | None = None,
        stream_compression: Tracing.StreamCompression | None = None,
        trace_config: Tracing.TraceConfig | None = None,
        perfetto_config: str | None = None,
        tracing_backend: Tracing.TracingBackend | None = None
    ):
        super().__init__(
            categories=categories,
            options=options,
            bufferUsageReportingInterval=buffer_usage_reporting_interval,
            transferMode=transfer_mode,
            streamFormat=stream_format,
            streamCompression=stream_compression,
            traceConfig=trace_config,
            perfettoConfig=perfetto_config,
            tracingBackend=tracing_backend
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows inspection of Web Audio API.
https://webaudio.github.io/web-audio-api/
https://chromedevtools.github.io/devtools-protocol/tot/WebAudio/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    WebAudio,
)
from cdpkit.protocol.base import CDPEvent


class ContextCreated(CDPEvent):
    """ Notifies that a new BaseAudioContext has been created. """

    context: WebAudio.BaseAudioContext


class ContextWillBeDestroyed(CDPEvent):
    """ Notifies that an existing BaseAudioContext will be destroyed. """

    contextId: WebAudio.GraphObjectId


class ContextChanged(CDPEvent):
    """ Notifies that existing BaseAudioContext has changed some properties (id stays the same).. """

    context: WebAudio.BaseAudioContext


class AudioListenerCreated(CDPEvent):
    """ Notifies that the construction of an AudioListener has finished. """

    listener: WebAudio.AudioListener


class AudioListenerWillBeDestroyed(CDPEvent):
    """ Notifies that a new AudioListener has been created. """

    contextId: WebAudio.GraphObjectId
    listenerId: WebAudio.GraphObjectId


class AudioNodeCreated(CDPEvent):
    """ Notifies that a new AudioNode has been created. """

    node: WebAudio.AudioNode


class AudioNodeWillBeDestroyed(CDPEvent):
    """ Notifies that an existing AudioNode has been destroyed. """

    contextId: WebAudio.GraphObjectId
    nodeId: WebAudio.GraphObjectId


class AudioParamCreated(CDPEvent):
    """ Notifies that a new AudioParam has been created. """

    param: WebAudio.AudioParam


class AudioParamWillBeDestroyed(CDPEvent):
    """ Notifies that an existing AudioParam has been destroyed. """

    contextId: WebAudio.GraphObjectId
    nodeId: WebAudio.GraphObjectId
    paramId: WebAudio.GraphObjectId


class NodesConnected(CDPEvent):
    """ Notifies that two AudioNodes are connected. """

    contextId: WebAudio.GraphObjectId
    sourceId: WebAudio.GraphObjectId
    destinationId: WebAudio.GraphObjectId
    sourceOutputIndex: float | None = None
    destinationInputIndex: float | None = None


class NodesDisconnected(CDPEvent):
    """ Notifies that AudioNodes are disconnected. The destination can be null, and it means all the outgoing connections from the source are disconnected. """

    contextId: WebAudio.GraphObjectId
    sourceId: WebAudio.GraphObjectId
    destinationId: WebAudio.GraphObjectId
    sourceOutputIndex: float | None = None
    destinationInputIndex: float | None = None


class NodeParamConnected(CDPEvent):
    """ Notifies that an AudioNode is connected to an AudioParam. """

    contextId: WebAudio.GraphObjectId
    sourceId: WebAudio.GraphObjectId
    destinationId: WebAudio.GraphObjectId
    sourceOutputIndex: float | None = None


class NodeParamDisconnected(CDPEvent):
    """ Notifies that an AudioNode is disconnected to an AudioParam. """

    contextId: WebAudio.GraphObjectId
    sourceId: WebAudio.GraphObjectId
    destinationId: WebAudio.GraphObjectId
    sourceOutputIndex: float | None = None



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Security/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    SecurityCertificateErrorAction,
    SecurityCertificateId,
    SecurityCertificateSecurityState,
    SecurityInsecureContentStatus,
    SecurityMixedContentType,
    SecuritySafetyTipInfo,
    SecuritySafetyTipStatus,
    SecuritySecurityState,
    SecuritySecurityStateExplanation,
    SecurityVisibleSecurityState,
)

CertificateId = SecurityCertificateId
MixedContentType = SecurityMixedContentType
SecurityState = SecuritySecurityState
CertificateSecurityState = SecurityCertificateSecurityState
SafetyTipStatus = SecuritySafetyTipStatus
SafetyTipInfo = SecuritySafetyTipInfo
VisibleSecurityState = SecurityVisibleSecurityState
SecurityStateExplanation = SecuritySecurityStateExplanation
InsecureContentStatus = SecurityInsecureContentStatus
CertificateErrorAction = SecurityCertificateErrorAction



from .events import VirtualTimeBudgetExpired
from .methods import (
    AddScreen,
    CanEmulate,
    ClearDeviceMetricsOverride,
    ClearDevicePostureOverride,
    ClearDisplayFeaturesOverride,
    ClearGeolocationOverride,
    ClearIdleOverride,
    GetOverriddenSensorInformation,
    GetScreenInfos,
    RemoveScreen,
    ResetPageScaleFactor,
    SetAutoDarkModeOverride,
    SetAutomationOverride,
    SetCPUThrottlingRate,
    SetDataSaverOverride,
    SetDefaultBackgroundColorOverride,
    SetDeviceMetricsOverride,
    SetDevicePostureOverride,
    SetDisabledImageTypes,
    SetDisplayFeaturesOverride,
    SetDocumentCookieDisabled,
    SetEmitTouchEventsForMouse,
    SetEmulatedMedia,
    SetEmulatedOSTextScale,
    SetEmulatedVisionDeficiency,
    SetFocusEmulationEnabled,
    SetGeolocationOverride,
    SetHardwareConcurrencyOverride,
    SetIdleOverride,
    SetLocaleOverride,
    SetNavigatorOverrides,
    SetPageScaleFactor,
    SetPressureDataOverride,
    SetPressureSourceOverrideEnabled,
    SetPressureStateOverride,
    SetSafeAreaInsetsOverride,
    SetScriptExecutionDisabled,
    SetScrollbarsHidden,
    SetSensorOverrideEnabled,
    SetSensorOverrideReadings,
    SetSmallViewportHeightDifferenceOverride,
    SetTimezoneOverride,
    SetTouchEmulationEnabled,
    SetUserAgentOverride,
    SetVirtualTimePolicy,
    SetVisibleSize,
)
from .types import (
    DevicePosture,
    DisabledImageType,
    DisplayFeature,
    MediaFeature,
    PressureMetadata,
    PressureSource,
    PressureState,
    SafeAreaInsets,
    ScreenId,
    ScreenInfo,
    ScreenOrientation,
    SensorMetadata,
    SensorReading,
    SensorReadingQuaternion,
    SensorReadingSingle,
    SensorReadingXYZ,
    SensorType,
    UserAgentBrandVersion,
    UserAgentMetadata,
    VirtualTimePolicy,
    WorkAreaInsets,
)

__all__ = [
    SafeAreaInsets,
    ScreenOrientation,
    DisplayFeature,
    DevicePosture,
    MediaFeature,
    VirtualTimePolicy,
    UserAgentBrandVersion,
    UserAgentMetadata,
    SensorType,
    SensorMetadata,
    SensorReadingSingle,
    SensorReadingXYZ,
    SensorReadingQuaternion,
    SensorReading,
    PressureSource,
    PressureState,
    PressureMetadata,
    WorkAreaInsets,
    ScreenId,
    ScreenInfo,
    DisabledImageType,
    VirtualTimeBudgetExpired,
    CanEmulate,
    ClearDeviceMetricsOverride,
    ClearGeolocationOverride,
    ResetPageScaleFactor,
    SetFocusEmulationEnabled,
    SetAutoDarkModeOverride,
    SetCPUThrottlingRate,
    SetDefaultBackgroundColorOverride,
    SetSafeAreaInsetsOverride,
    SetDeviceMetricsOverride,
    SetDevicePostureOverride,
    ClearDevicePostureOverride,
    SetDisplayFeaturesOverride,
    ClearDisplayFeaturesOverride,
    SetScrollbarsHidden,
    SetDocumentCookieDisabled,
    SetEmitTouchEventsForMouse,
    SetEmulatedMedia,
    SetEmulatedVisionDeficiency,
    SetEmulatedOSTextScale,
    SetGeolocationOverride,
    GetOverriddenSensorInformation,
    SetSensorOverrideEnabled,
    SetSensorOverrideReadings,
    SetPressureSourceOverrideEnabled,
    SetPressureStateOverride,
    SetPressureDataOverride,
    SetIdleOverride,
    ClearIdleOverride,
    SetNavigatorOverrides,
    SetPageScaleFactor,
    SetScriptExecutionDisabled,
    SetTouchEmulationEnabled,
    SetVirtualTimePolicy,
    SetLocaleOverride,
    SetTimezoneOverride,
    SetVisibleSize,
    SetDisabledImageTypes,
    SetDataSaverOverride,
    SetHardwareConcurrencyOverride,
    SetUserAgentOverride,
    SetAutomationOverride,
    SetSmallViewportHeightDifferenceOverride,
    GetScreenInfos,
    AddScreen,
    RemoveScreen,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Query and modify DOM storage.
https://chromedevtools.github.io/devtools-protocol/tot/DOMStorage/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOMStorage,
)
from cdpkit.protocol.base import CDPEvent


class DomStorageItemAdded(CDPEvent):

    storageId: DOMStorage.StorageId
    key: str
    newValue: str


class DomStorageItemRemoved(CDPEvent):

    storageId: DOMStorage.StorageId
    key: str


class DomStorageItemUpdated(CDPEvent):

    storageId: DOMStorage.StorageId
    key: str
    oldValue: str
    newValue: str


class DomStorageItemsCleared(CDPEvent):

    storageId: DOMStorage.StorageId



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Network domain allows tracking network activities of the page. It exposes information about http,
file, data and other requests and responses, their headers, bodies, timing, etc.
https://chromedevtools.github.io/devtools-protocol/tot/Network/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    IO,
    Debugger,
    Emulation,
    Network,
    Page,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class SetAcceptedEncodingsInput(InputModel):

    encodings: list[Network.ContentEncoding]


class SetAcceptedEncodings(CDPMethod[None]):  # experimental
    """ Sets a list of content encodings that will be accepted. Empty list means no encoding is accepted. """

    INPUT_VALIDATOR = SetAcceptedEncodingsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        encodings: list[Network.ContentEncoding]
    ):
        super().__init__(
            encodings=encodings
        )


class ClearAcceptedEncodingsOverride(CDPMethod[None]):  # experimental
    """ Clears accepted encodings set by setAcceptedEncodings """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class CanClearBrowserCacheOutput(OutputModel):

    result: bool


class CanClearBrowserCache(CDPMethod[CanClearBrowserCacheOutput]):  # deprecated
    """ Tells whether clearing browser cache is supported. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = CanClearBrowserCacheOutput


class CanClearBrowserCookiesOutput(OutputModel):

    result: bool


class CanClearBrowserCookies(CDPMethod[CanClearBrowserCookiesOutput]):  # deprecated
    """ Tells whether clearing browser cookies is supported. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = CanClearBrowserCookiesOutput


class CanEmulateNetworkConditionsOutput(OutputModel):

    result: bool


class CanEmulateNetworkConditions(CDPMethod[CanEmulateNetworkConditionsOutput]):  # deprecated
    """ Tells whether emulation of network conditions is supported. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = CanEmulateNetworkConditionsOutput


class ClearBrowserCache(CDPMethod[None]):
    """ Clears browser cache. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class ClearBrowserCookies(CDPMethod[None]):
    """ Clears browser cookies. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class ContinueInterceptedRequestInput(InputModel):

    interceptionId: Network.InterceptionId
    errorReason: Network.ErrorReason | None = None
    rawResponse: str | None = None
    url: str | None = None
    method: str | None = None
    postData: str | None = None
    headers: Network.Headers | None = None
    authChallengeResponse: Network.AuthChallengeResponse | None = None


class ContinueInterceptedRequest(CDPMethod[None]):  # experimental deprecated
    """ Response to Network.requestIntercepted which either modifies the request to continue with any
    modifications, or blocks it, or completes it with the provided response bytes. If a network
    fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted
    event will be sent with the same InterceptionId.
    Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead. """

    INPUT_VALIDATOR = ContinueInterceptedRequestInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        interception_id: Network.InterceptionId,
        error_reason: Network.ErrorReason | None = None,
        raw_response: str | None = None,
        url: str | None = None,
        method: str | None = None,
        post_data: str | None = None,
        headers: Network.Headers | None = None,
        auth_challenge_response: Network.AuthChallengeResponse | None = None
    ):
        super().__init__(
            interceptionId=interception_id,
            errorReason=error_reason,
            rawResponse=raw_response,
            url=url,
            method=method,
            postData=post_data,
            headers=headers,
            authChallengeResponse=auth_challenge_response
        )


class DeleteCookiesInput(InputModel):

    name: str
    url: str | None = None
    domain: str | None = None
    path: str | None = None
    partitionKey: Network.CookiePartitionKey | None = None  # experimental


class DeleteCookies(CDPMethod[None]):
    """ Deletes browser cookies with matching name and url or domain/path/partitionKey pair. """

    INPUT_VALIDATOR = DeleteCookiesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        name: str,
        url: str | None = None,
        domain: str | None = None,
        path: str | None = None,
        partition_key: Network.CookiePartitionKey | None = None
    ):
        super().__init__(
            name=name,
            url=url,
            domain=domain,
            path=path,
            partitionKey=partition_key
        )


class Disable(CDPMethod[None]):
    """ Disables network tracking, prevents network events from being sent to the client. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class EmulateNetworkConditionsInput(InputModel):

    offline: bool
    latency: float
    downloadThroughput: float
    uploadThroughput: float
    connectionType: Network.ConnectionType | None = None
    packetLoss: float | None = None  # experimental
    packetQueueLength: int | None = None  # experimental
    packetReordering: bool | None = None  # experimental


class EmulateNetworkConditions(CDPMethod[None]):  # deprecated
    """ Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule
    and overrideNetworkState commands, which can be used together to the same effect. """

    INPUT_VALIDATOR = EmulateNetworkConditionsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        offline: bool,
        latency: float,
        download_throughput: float,
        upload_throughput: float,
        connection_type: Network.ConnectionType | None = None,
        packet_loss: float | None = None,
        packet_queue_length: int | None = None,
        packet_reordering: bool | None = None
    ):
        super().__init__(
            offline=offline,
            latency=latency,
            downloadThroughput=download_throughput,
            uploadThroughput=upload_throughput,
            connectionType=connection_type,
            packetLoss=packet_loss,
            packetQueueLength=packet_queue_length,
            packetReordering=packet_reordering
        )


class EmulateNetworkConditionsByRuleInput(InputModel):

    offline: bool
    matchedNetworkConditions: list[Network.NetworkConditions]


class EmulateNetworkConditionsByRuleOutput(OutputModel):

    ruleIds: list[str]


class EmulateNetworkConditionsByRule(CDPMethod[EmulateNetworkConditionsByRuleOutput]):  # experimental
    """ Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated
    Network.emulateNetworkConditions this method does not affect `navigator` state. Use Network.overrideNetworkState to
    explicitly modify `navigator` behavior. """

    INPUT_VALIDATOR = EmulateNetworkConditionsByRuleInput
    OUTPUT_VALIDATOR = EmulateNetworkConditionsByRuleOutput

    def __init__(
        self,
        *,
        offline: bool,
        matched_network_conditions: list[Network.NetworkConditions]
    ):
        super().__init__(
            offline=offline,
            matchedNetworkConditions=matched_network_conditions
        )


class OverrideNetworkStateInput(InputModel):

    offline: bool
    latency: float
    downloadThroughput: float
    uploadThroughput: float
    connectionType: Network.ConnectionType | None = None


class OverrideNetworkState(CDPMethod[None]):  # experimental
    """ Override the state of navigator.onLine and navigator.connection. """

    INPUT_VALIDATOR = OverrideNetworkStateInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        offline: bool,
        latency: float,
        download_throughput: float,
        upload_throughput: float,
        connection_type: Network.ConnectionType | None = None
    ):
        super().__init__(
            offline=offline,
            latency=latency,
            downloadThroughput=download_throughput,
            uploadThroughput=upload_throughput,
            connectionType=connection_type
        )


class EnableInput(InputModel):

    maxTotalBufferSize: int | None = None  # experimental
    maxResourceBufferSize: int | None = None  # experimental
    maxPostDataSize: int | None = None
    reportDirectSocketTraffic: bool | None = None  # experimental
    enableDurableMessages: bool | None = None  # experimental


class Enable(CDPMethod[None]):
    """ Enables network tracking, network events will now be delivered to the client. """

    INPUT_VALIDATOR = EnableInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        max_total_buffer_size: int | None = None,
        max_resource_buffer_size: int | None = None,
        max_post_data_size: int | None = None,
        report_direct_socket_traffic: bool | None = None,
        enable_durable_messages: bool | None = None
    ):
        super().__init__(
            maxTotalBufferSize=max_total_buffer_size,
            maxResourceBufferSize=max_resource_buffer_size,
            maxPostDataSize=max_post_data_size,
            reportDirectSocketTraffic=report_direct_socket_traffic,
            enableDurableMessages=enable_durable_messages
        )


class ConfigureDurableMessagesInput(InputModel):

    maxTotalBufferSize: int | None = None
    maxResourceBufferSize: int | None = None


class ConfigureDurableMessages(CDPMethod[None]):  # experimental
    """ Configures storing response bodies outside of renderer, so that these survive
    a cross-process navigation.
    If maxTotalBufferSize is not set, durable messages are disabled. """

    INPUT_VALIDATOR = ConfigureDurableMessagesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        max_total_buffer_size: int | None = None,
        max_resource_buffer_size: int | None = None
    ):
        super().__init__(
            maxTotalBufferSize=max_total_buffer_size,
            maxResourceBufferSize=max_resource_buffer_size
        )


class GetAllCookiesOutput(OutputModel):

    cookies: list[Network.Cookie]


class GetAllCookies(CDPMethod[GetAllCookiesOutput]):  # deprecated
    """ Returns all browser cookies. Depending on the backend support, will return detailed cookie
    information in the `cookies` field.
    Deprecated. Use Storage.getCookies instead. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetAllCookiesOutput


class GetCertificateInput(InputModel):

    origin: str


class GetCertificateOutput(OutputModel):

    tableNames: list[str]


class GetCertificate(CDPMethod[GetCertificateOutput]):  # experimental
    """ Returns the DER-encoded certificate. """

    INPUT_VALIDATOR = GetCertificateInput
    OUTPUT_VALIDATOR = GetCertificateOutput

    def __init__(
        self,
        *,
        origin: str
    ):
        super().__init__(
            origin=origin
        )


class GetCookiesInput(InputModel):

    urls: list[str] | None = None


class GetCookiesOutput(OutputModel):

    cookies: list[Network.Cookie]


class GetCookies(CDPMethod[GetCookiesOutput]):
    """ Returns all browser cookies for the current URL. Depending on the backend support, will return
    detailed cookie information in the `cookies` field. """

    INPUT_VALIDATOR = GetCookiesInput
    OUTPUT_VALIDATOR = GetCookiesOutput

    def __init__(
        self,
        *,
        urls: list[str] | None = None
    ):
        super().__init__(
            urls=urls
        )


class GetResponseBodyInput(InputModel):

    requestId: Network.RequestId


class GetResponseBodyOutput(OutputModel):

    body: str
    base64Encoded: bool


class GetResponseBody(CDPMethod[GetResponseBodyOutput]):
    """ Returns content served for the given request. """

    INPUT_VALIDATOR = GetResponseBodyInput
    OUTPUT_VALIDATOR = GetResponseBodyOutput

    def __init__(
        self,
        *,
        request_id: Network.RequestId
    ):
        super().__init__(
            requestId=request_id
        )


class GetRequestPostDataInput(InputModel):

    requestId: Network.RequestId


class GetRequestPostDataOutput(OutputModel):

    postData: str


class GetRequestPostData(CDPMethod[GetRequestPostDataOutput]):
    """ Returns post data sent with the request. Returns an error when no data was sent with the request. """

    INPUT_VALIDATOR = GetRequestPostDataInput
    OUTPUT_VALIDATOR = GetRequestPostDataOutput

    def __init__(
        self,
        *,
        request_id: Network.RequestId
    ):
        super().__init__(
            requestId=request_id
        )


class GetResponseBodyForInterceptionInput(InputModel):

    interceptionId: Network.InterceptionId


class GetResponseBodyForInterceptionOutput(OutputModel):

    body: str
    base64Encoded: bool


class GetResponseBodyForInterception(CDPMethod[GetResponseBodyForInterceptionOutput]):  # experimental
    """ Returns content served for the given currently intercepted request. """

    INPUT_VALIDATOR = GetResponseBodyForInterceptionInput
    OUTPUT_VALIDATOR = GetResponseBodyForInterceptionOutput

    def __init__(
        self,
        *,
        interception_id: Network.InterceptionId
    ):
        super().__init__(
            interceptionId=interception_id
        )


class TakeResponseBodyForInterceptionAsStreamInput(InputModel):

    interceptionId: Network.InterceptionId


class TakeResponseBodyForInterceptionAsStreamOutput(OutputModel):

    stream: IO.StreamHandle


class TakeResponseBodyForInterceptionAsStream(CDPMethod[TakeResponseBodyForInterceptionAsStreamOutput]):  # experimental
    """ Returns a handle to the stream representing the response body. Note that after this command,
    the intercepted request can't be continued as is -- you either need to cancel it or to provide
    the response body. The stream only supports sequential read, IO.read will fail if the position
    is specified. """

    INPUT_VALIDATOR = TakeResponseBodyForInterceptionAsStreamInput
    OUTPUT_VALIDATOR = TakeResponseBodyForInterceptionAsStreamOutput

    def __init__(
        self,
        *,
        interception_id: Network.InterceptionId
    ):
        super().__init__(
            interceptionId=interception_id
        )


class ReplayXHRInput(InputModel):

    requestId: Network.RequestId


class ReplayXHR(CDPMethod[None]):  # experimental
    """ This method sends a new XMLHttpRequest which is identical to the original one. The following
    parameters should be identical: method, url, async, request body, extra headers, withCredentials
    attribute, user, password. """

    INPUT_VALIDATOR = ReplayXHRInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        request_id: Network.RequestId
    ):
        super().__init__(
            requestId=request_id
        )


class SearchInResponseBodyInput(InputModel):

    requestId: Network.RequestId
    query: str
    caseSensitive: bool | None = None
    isRegex: bool | None = None


class SearchInResponseBodyOutput(OutputModel):

    result: list[Debugger.SearchMatch]


class SearchInResponseBody(CDPMethod[SearchInResponseBodyOutput]):  # experimental
    """ Searches for given string in response content. """

    INPUT_VALIDATOR = SearchInResponseBodyInput
    OUTPUT_VALIDATOR = SearchInResponseBodyOutput

    def __init__(
        self,
        *,
        request_id: Network.RequestId,
        query: str,
        case_sensitive: bool | None = None,
        is_regex: bool | None = None
    ):
        super().__init__(
            requestId=request_id,
            query=query,
            caseSensitive=case_sensitive,
            isRegex=is_regex
        )


class SetBlockedURLsInput(InputModel):

    urlPatterns: list[Network.BlockPattern] | None = None
    urls: list[str] | None = None  # deprecated


class SetBlockedURLs(CDPMethod[None]):  # experimental
    """ Blocks URLs from loading. """

    INPUT_VALIDATOR = SetBlockedURLsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        url_patterns: list[Network.BlockPattern] | None = None,
        urls: list[str] | None = None
    ):
        super().__init__(
            urlPatterns=url_patterns,
            urls=urls
        )


class SetBypassServiceWorkerInput(InputModel):

    bypass: bool


class SetBypassServiceWorker(CDPMethod[None]):
    """ Toggles ignoring of service worker for each request. """

    INPUT_VALIDATOR = SetBypassServiceWorkerInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        bypass: bool
    ):
        super().__init__(
            bypass=bypass
        )


class SetCacheDisabledInput(InputModel):

    cacheDisabled: bool


class SetCacheDisabled(CDPMethod[None]):
    """ Toggles ignoring cache for each request. If `true`, cache will not be used. """

    INPUT_VALIDATOR = SetCacheDisabledInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        cache_disabled: bool
    ):
        super().__init__(
            cacheDisabled=cache_disabled
        )


class SetCookieInput(InputModel):

    name: str
    value: str
    url: str | None = None
    domain: str | None = None
    path: str | None = None
    secure: bool | None = None
    httpOnly: bool | None = None
    sameSite: Network.CookieSameSite | None = None
    expires: Network.TimeSinceEpoch | None = None
    priority: Network.CookiePriority | None = None  # experimental
    sameParty: bool | None = None  # experimental
    sourceScheme: Network.CookieSourceScheme | None = None  # experimental
    sourcePort: int | None = None  # experimental
    partitionKey: Network.CookiePartitionKey | None = None  # experimental


class SetCookieOutput(OutputModel):

    success: bool  # deprecated


class SetCookie(CDPMethod[SetCookieOutput]):
    """ Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist. """

    INPUT_VALIDATOR = SetCookieInput
    OUTPUT_VALIDATOR = SetCookieOutput

    def __init__(
        self,
        *,
        name: str,
        value: str,
        url: str | None = None,
        domain: str | None = None,
        path: str | None = None,
        secure: bool | None = None,
        http_only: bool | None = None,
        same_site: Network.CookieSameSite | None = None,
        expires: Network.TimeSinceEpoch | None = None,
        priority: Network.CookiePriority | None = None,
        same_party: bool | None = None,
        source_scheme: Network.CookieSourceScheme | None = None,
        source_port: int | None = None,
        partition_key: Network.CookiePartitionKey | None = None
    ):
        super().__init__(
            name=name,
            value=value,
            url=url,
            domain=domain,
            path=path,
            secure=secure,
            httpOnly=http_only,
            sameSite=same_site,
            expires=expires,
            priority=priority,
            sameParty=same_party,
            sourceScheme=source_scheme,
            sourcePort=source_port,
            partitionKey=partition_key
        )


class SetCookiesInput(InputModel):

    cookies: list[Network.CookieParam]


class SetCookies(CDPMethod[None]):
    """ Sets given cookies. """

    INPUT_VALIDATOR = SetCookiesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        cookies: list[Network.CookieParam]
    ):
        super().__init__(
            cookies=cookies
        )


class SetExtraHTTPHeadersInput(InputModel):

    headers: Network.Headers


class SetExtraHTTPHeaders(CDPMethod[None]):
    """ Specifies whether to always send extra HTTP headers with the requests from this page. """

    INPUT_VALIDATOR = SetExtraHTTPHeadersInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        headers: Network.Headers
    ):
        super().__init__(
            headers=headers
        )


class SetAttachDebugStackInput(InputModel):

    enabled: bool


class SetAttachDebugStack(CDPMethod[None]):  # experimental
    """ Specifies whether to attach a page script stack id in requests """

    INPUT_VALIDATOR = SetAttachDebugStackInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool
    ):
        super().__init__(
            enabled=enabled
        )


class SetRequestInterceptionInput(InputModel):

    patterns: list[Network.RequestPattern]


class SetRequestInterception(CDPMethod[None]):  # experimental deprecated
    """ Sets the requests to intercept that match the provided patterns and optionally resource types.
    Deprecated, please use Fetch.enable instead. """

    INPUT_VALIDATOR = SetRequestInterceptionInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        patterns: list[Network.RequestPattern]
    ):
        super().__init__(
            patterns=patterns
        )


class SetUserAgentOverrideInput(InputModel):

    userAgent: str
    acceptLanguage: str | None = None
    platform: str | None = None
    userAgentMetadata: Emulation.UserAgentMetadata | None = None  # experimental


class SetUserAgentOverride(CDPMethod[None]):
    """ Allows overriding user agent with the given string. """

    INPUT_VALIDATOR = SetUserAgentOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        user_agent: str,
        accept_language: str | None = None,
        platform: str | None = None,
        user_agent_metadata: Emulation.UserAgentMetadata | None = None
    ):
        super().__init__(
            userAgent=user_agent,
            acceptLanguage=accept_language,
            platform=platform,
            userAgentMetadata=user_agent_metadata
        )


class StreamResourceContentInput(InputModel):

    requestId: Network.RequestId


class StreamResourceContentOutput(OutputModel):

    bufferedData: str


class StreamResourceContent(CDPMethod[StreamResourceContentOutput]):  # experimental
    """ Enables streaming of the response for the given requestId.
    If enabled, the dataReceived event contains the data that was received during streaming. """

    INPUT_VALIDATOR = StreamResourceContentInput
    OUTPUT_VALIDATOR = StreamResourceContentOutput

    def __init__(
        self,
        *,
        request_id: Network.RequestId
    ):
        super().__init__(
            requestId=request_id
        )


class GetSecurityIsolationStatusInput(InputModel):

    frameId: Page.FrameId | None = None


class GetSecurityIsolationStatusOutput(OutputModel):

    status: Network.SecurityIsolationStatus


class GetSecurityIsolationStatus(CDPMethod[GetSecurityIsolationStatusOutput]):  # experimental
    """ Returns information about the COEP/COOP isolation status. """

    INPUT_VALIDATOR = GetSecurityIsolationStatusInput
    OUTPUT_VALIDATOR = GetSecurityIsolationStatusOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId | None = None
    ):
        super().__init__(
            frameId=frame_id
        )


class EnableReportingApiInput(InputModel):

    enable: bool


class EnableReportingApi(CDPMethod[None]):  # experimental
    """ Enables tracking for the Reporting API, events generated by the Reporting API will now be delivered to the client.
    Enabling triggers 'reportingApiReportAdded' for all existing reports. """

    INPUT_VALIDATOR = EnableReportingApiInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enable: bool
    ):
        super().__init__(
            enable=enable
        )


class LoadNetworkResourceInput(InputModel):

    frameId: Page.FrameId | None = None
    url: str
    options: Network.LoadNetworkResourceOptions


class LoadNetworkResourceOutput(OutputModel):

    resource: Network.LoadNetworkResourcePageResult


class LoadNetworkResource(CDPMethod[LoadNetworkResourceOutput]):  # experimental
    """ Fetches the resource and returns the content. """

    INPUT_VALIDATOR = LoadNetworkResourceInput
    OUTPUT_VALIDATOR = LoadNetworkResourceOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId | None = None,
        url: str,
        options: Network.LoadNetworkResourceOptions
    ):
        super().__init__(
            frameId=frame_id,
            url=url,
            options=options
        )


class SetCookieControlsInput(InputModel):

    enableThirdPartyCookieRestriction: bool
    disableThirdPartyCookieMetadata: bool
    disableThirdPartyCookieHeuristics: bool


class SetCookieControls(CDPMethod[None]):  # experimental
    """ Sets Controls for third-party cookie access
    Page reload is required before the new cookie behavior will be observed """

    INPUT_VALIDATOR = SetCookieControlsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enable_third_party_cookie_restriction: bool,
        disable_third_party_cookie_metadata: bool,
        disable_third_party_cookie_heuristics: bool
    ):
        super().__init__(
            enableThirdPartyCookieRestriction=enable_third_party_cookie_restriction,
            disableThirdPartyCookieMetadata=disable_third_party_cookie_metadata,
            disableThirdPartyCookieHeuristics=disable_third_party_cookie_heuristics
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain is deprecated - use Runtime or Log instead.
https://chromedevtools.github.io/devtools-protocol/tot/Console/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Console,
)
from cdpkit.protocol.base import CDPEvent


class MessageAdded(CDPEvent):
    """ Issued when new console message is added. """

    message: Console.ConsoleMessage



from .events import TimelineEventAdded
from .methods import Enable
from .types import LargestContentfulPaint, LayoutShift, LayoutShiftAttribution, TimelineEvent

__all__ = [
    LargestContentfulPaint,
    LayoutShiftAttribution,
    LayoutShift,
    TimelineEvent,
    TimelineEventAdded,
    Enable,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/CacheStorage/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    CacheStorageCache,
    CacheStorageCachedResponse,
    CacheStorageCachedResponseType,
    CacheStorageCacheId,
    CacheStorageDataEntry,
    CacheStorageHeader,
)

CacheId = CacheStorageCacheId
CachedResponseType = CacheStorageCachedResponseType
DataEntry = CacheStorageDataEntry
Cache = CacheStorageCache
Header = CacheStorageHeader
CachedResponse = CacheStorageCachedResponse



from .events import Detached, TargetCrashed, TargetReloadedAfterCrash, WorkerScriptLoaded
from .methods import Disable, Enable

__all__ = [
    Detached,
    TargetCrashed,
    TargetReloadedAfterCrash,
    WorkerScriptLoaded,
    Disable,
    Enable,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Performance/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    Performance,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class Disable(CDPMethod[None]):
    """ Disable collecting and reporting metrics. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class EnableInput(InputModel):

    timeDomain: Literal['timeTicks', 'threadTicks'] | None = None


class Enable(CDPMethod[None]):
    """ Enable collecting and reporting metrics. """

    INPUT_VALIDATOR = EnableInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        time_domain: Literal['timeTicks', 'threadTicks'] | None = None
    ):
        super().__init__(
            timeDomain=time_domain
        )


class SetTimeDomainInput(InputModel):

    timeDomain: Literal['timeTicks', 'threadTicks']


class SetTimeDomain(CDPMethod[None]):  # experimental deprecated
    """ Sets time domain to use for collecting and reporting duration metrics.
    Note that this must be called before enabling metrics collection. Calling
    this method while metrics collection is enabled returns an error. """

    INPUT_VALIDATOR = SetTimeDomainInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        time_domain: Literal['timeTicks', 'threadTicks']
    ):
        super().__init__(
            timeDomain=time_domain
        )


class GetMetricsOutput(OutputModel):

    metrics: list[Performance.Metric]


class GetMetrics(CDPMethod[GetMetricsOutput]):
    """ Retrieve current values of run-time metrics. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetMetricsOutput



from .events import AnimationCanceled, AnimationCreated, AnimationStarted, AnimationUpdated
from .methods import (
    Disable,
    Enable,
    GetCurrentTime,
    GetPlaybackRate,
    ReleaseAnimations,
    ResolveAnimation,
    SeekAnimations,
    SetPaused,
    SetPlaybackRate,
    SetTiming,
)
from .types import Animation, AnimationEffect, KeyframesRule, KeyframeStyle, ViewOrScrollTimeline

__all__ = [
    Animation,
    ViewOrScrollTimeline,
    AnimationEffect,
    KeyframesRule,
    KeyframeStyle,
    AnimationCanceled,
    AnimationCreated,
    AnimationStarted,
    AnimationUpdated,
    Disable,
    Enable,
    GetCurrentTime,
    GetPlaybackRate,
    ReleaseAnimations,
    ResolveAnimation,
    SeekAnimations,
    SetPaused,
    SetPlaybackRate,
    SetTiming,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Provides access to log entries.
https://chromedevtools.github.io/devtools-protocol/tot/Log/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Log,
)
from cdpkit.protocol.base import CDPEvent


class EntryAdded(CDPEvent):
    """ Issued when new message was logged. """

    entry: Log.LogEntry



from .events import (
    AdoptedStyleSheetsModified,
    AffectedByStartingStylesFlagUpdated,
    AttributeModified,
    AttributeRemoved,
    CharacterDataModified,
    ChildNodeCountUpdated,
    ChildNodeInserted,
    ChildNodeRemoved,
    DistributedNodesUpdated,
    DocumentUpdated,
    InlineStyleInvalidated,
    PseudoElementAdded,
    PseudoElementRemoved,
    ScrollableFlagUpdated,
    SetChildNodes,
    ShadowRootPopped,
    ShadowRootPushed,
    TopLayerElementsUpdated,
)
from .methods import (
    CollectClassNamesFromSubtree,
    CopyTo,
    DescribeNode,
    Disable,
    DiscardSearchResults,
    Enable,
    Focus,
    ForceShowPopover,
    GetAnchorElement,
    GetAttributes,
    GetBoxModel,
    GetContainerForNode,
    GetContentQuads,
    GetDetachedDomNodes,
    GetDocument,
    GetElementByRelation,
    GetFileInfo,
    GetFlattenedDocument,
    GetFrameOwner,
    GetNodeForLocation,
    GetNodesForSubtreeByStyle,
    GetNodeStackTraces,
    GetOuterHTML,
    GetQueryingDescendantsForContainer,
    GetRelayoutBoundary,
    GetSearchResults,
    GetTopLayerElements,
    HideHighlight,
    HighlightNode,
    HighlightRect,
    MarkUndoableState,
    MoveTo,
    PerformSearch,
    PushNodeByPathToFrontend,
    PushNodesByBackendIdsToFrontend,
    QuerySelector,
    QuerySelectorAll,
    Redo,
    RemoveAttribute,
    RemoveNode,
    RequestChildNodes,
    RequestNode,
    ResolveNode,
    ScrollIntoViewIfNeeded,
    SetAttributesAsText,
    SetAttributeValue,
    SetFileInputFiles,
    SetInspectedNode,
    SetNodeName,
    SetNodeStackTracesEnabled,
    SetNodeValue,
    SetOuterHTML,
    Undo,
)
from .types import (
    RGBA,
    BackendNode,
    BackendNodeId,
    BoxModel,
    CompatibilityMode,
    CSSComputedStyleProperty,
    DetachedElementInfo,
    LogicalAxes,
    Node,
    NodeId,
    PhysicalAxes,
    PseudoType,
    Quad,
    Rect,
    ScrollOrientation,
    ShadowRootType,
    ShapeOutsideInfo,
    StyleSheetId,
)

__all__ = [
    NodeId,
    BackendNodeId,
    StyleSheetId,
    BackendNode,
    PseudoType,
    ShadowRootType,
    CompatibilityMode,
    PhysicalAxes,
    LogicalAxes,
    ScrollOrientation,
    Node,
    DetachedElementInfo,
    RGBA,
    Quad,
    BoxModel,
    ShapeOutsideInfo,
    Rect,
    CSSComputedStyleProperty,
    AttributeModified,
    AdoptedStyleSheetsModified,
    AttributeRemoved,
    CharacterDataModified,
    ChildNodeCountUpdated,
    ChildNodeInserted,
    ChildNodeRemoved,
    DistributedNodesUpdated,
    DocumentUpdated,
    InlineStyleInvalidated,
    PseudoElementAdded,
    TopLayerElementsUpdated,
    ScrollableFlagUpdated,
    AffectedByStartingStylesFlagUpdated,
    PseudoElementRemoved,
    SetChildNodes,
    ShadowRootPopped,
    ShadowRootPushed,
    CollectClassNamesFromSubtree,
    CopyTo,
    DescribeNode,
    ScrollIntoViewIfNeeded,
    Disable,
    DiscardSearchResults,
    Enable,
    Focus,
    GetAttributes,
    GetBoxModel,
    GetContentQuads,
    GetDocument,
    GetFlattenedDocument,
    GetNodesForSubtreeByStyle,
    GetNodeForLocation,
    GetOuterHTML,
    GetRelayoutBoundary,
    GetSearchResults,
    HideHighlight,
    HighlightNode,
    HighlightRect,
    MarkUndoableState,
    MoveTo,
    PerformSearch,
    PushNodeByPathToFrontend,
    PushNodesByBackendIdsToFrontend,
    QuerySelector,
    QuerySelectorAll,
    GetTopLayerElements,
    GetElementByRelation,
    Redo,
    RemoveAttribute,
    RemoveNode,
    RequestChildNodes,
    RequestNode,
    ResolveNode,
    SetAttributeValue,
    SetAttributesAsText,
    SetFileInputFiles,
    SetNodeStackTracesEnabled,
    GetNodeStackTraces,
    GetFileInfo,
    GetDetachedDomNodes,
    SetInspectedNode,
    SetNodeName,
    SetNodeValue,
    SetOuterHTML,
    Undo,
    GetFrameOwner,
    GetContainerForNode,
    GetQueryingDescendantsForContainer,
    GetAnchorElement,
    ForceShowPopover,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows configuring virtual Bluetooth devices to test
the web-bluetooth API.
https://chromedevtools.github.io/devtools-protocol/tot/BluetoothEmulation/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    BluetoothEmulationCentralState,
    BluetoothEmulationCharacteristicOperationType,
    BluetoothEmulationCharacteristicProperties,
    BluetoothEmulationCharacteristicWriteType,
    BluetoothEmulationDescriptorOperationType,
    BluetoothEmulationGATTOperationType,
    BluetoothEmulationManufacturerData,
    BluetoothEmulationScanEntry,
    BluetoothEmulationScanRecord,
)

CentralState = BluetoothEmulationCentralState
GATTOperationType = BluetoothEmulationGATTOperationType
CharacteristicWriteType = BluetoothEmulationCharacteristicWriteType
CharacteristicOperationType = BluetoothEmulationCharacteristicOperationType
DescriptorOperationType = BluetoothEmulationDescriptorOperationType
ManufacturerData = BluetoothEmulationManufacturerData
ScanRecord = BluetoothEmulationScanRecord
ScanEntry = BluetoothEmulationScanEntry
CharacteristicProperties = BluetoothEmulationCharacteristicProperties



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain exposes DOM read/write operations. Each DOM Node is represented with its mirror object
that has an `id`. This `id` can be used to get additional information on the Node, resolve it into
the JavaScript object wrapper, etc. It is important that client receives DOM events only for the
nodes that are known to the client. Backend keeps track of the nodes that were sent to the client
and never sends the same node twice. It is client's responsibility to collect information about
the nodes that were sent to the client. Note that `iframe` owner elements will return
corresponding document elements as their child nodes.
https://chromedevtools.github.io/devtools-protocol/tot/DOM/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOMRGBA,
    DOMBackendNode,
    DOMBackendNodeId,
    DOMBoxModel,
    DOMCompatibilityMode,
    DOMCSSComputedStyleProperty,
    DOMDetachedElementInfo,
    DOMLogicalAxes,
    DOMNode,
    DOMNodeId,
    DOMPhysicalAxes,
    DOMPseudoType,
    DOMQuad,
    DOMRect,
    DOMScrollOrientation,
    DOMShadowRootType,
    DOMShapeOutsideInfo,
    DOMStyleSheetId,
)

NodeId = DOMNodeId
BackendNodeId = DOMBackendNodeId
StyleSheetId = DOMStyleSheetId
BackendNode = DOMBackendNode
PseudoType = DOMPseudoType
ShadowRootType = DOMShadowRootType
CompatibilityMode = DOMCompatibilityMode
PhysicalAxes = DOMPhysicalAxes
LogicalAxes = DOMLogicalAxes
ScrollOrientation = DOMScrollOrientation
Node = DOMNode
DetachedElementInfo = DOMDetachedElementInfo
RGBA = DOMRGBA
Quad = DOMQuad
BoxModel = DOMBoxModel
ShapeOutsideInfo = DOMShapeOutsideInfo
Rect = DOMRect
CSSComputedStyleProperty = DOMCSSComputedStyleProperty



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Tracing/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    IO,
    Tracing,
)
from cdpkit.protocol.base import JSON_DICT, CDPEvent


class BufferUsage(CDPEvent):

    percentFull: float | None = None
    eventCount: float | None = None
    value: float | None = None


class DataCollected(CDPEvent):
    """ Contains a bucket of collected trace events. When tracing is stopped collected events will be
    sent as a sequence of dataCollected events followed by tracingComplete event. """

    value: list[JSON_DICT]


class TracingComplete(CDPEvent):
    """ Signals that tracing is stopped and there is no trace buffers pending flush, all data were
    delivered via dataCollected events. """

    dataLossOccurred: bool
    stream: IO.StreamHandle | None = None
    traceFormat: Tracing.StreamFormat | None = None
    streamCompression: Tracing.StreamCompression | None = None



from .methods import (
    GetEventListeners,
    RemoveDOMBreakpoint,
    RemoveEventListenerBreakpoint,
    RemoveInstrumentationBreakpoint,
    RemoveXHRBreakpoint,
    SetBreakOnCSPViolation,
    SetDOMBreakpoint,
    SetEventListenerBreakpoint,
    SetInstrumentationBreakpoint,
    SetXHRBreakpoint,
)
from .types import CSPViolationType, DOMBreakpointType, EventListener

__all__ = [
    DOMBreakpointType,
    CSPViolationType,
    EventListener,
    GetEventListeners,
    RemoveDOMBreakpoint,
    RemoveEventListenerBreakpoint,
    RemoveInstrumentationBreakpoint,
    RemoveXHRBreakpoint,
    SetBreakOnCSPViolation,
    SetDOMBreakpoint,
    SetEventListenerBreakpoint,
    SetInstrumentationBreakpoint,
    SetXHRBreakpoint,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

A domain for interacting with Cast, Presentation API, and Remote Playback API
functionalities.
https://chromedevtools.github.io/devtools-protocol/tot/Cast/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol.base import CDPMethod, InputModel


class EnableInput(InputModel):

    presentationUrl: str | None = None


class Enable(CDPMethod[None]):
    """ Starts observing for sinks that can be used for tab mirroring, and if set,
    sinks compatible with |presentationUrl| as well. When sinks are found, a
    |sinksUpdated| event is fired.
    Also starts observing for issue messages. When an issue is added or removed,
    an |issueUpdated| event is fired. """

    INPUT_VALIDATOR = EnableInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        presentation_url: str | None = None
    ):
        super().__init__(
            presentationUrl=presentation_url
        )


class Disable(CDPMethod[None]):
    """ Stops observing for sinks and issues. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class SetSinkToUseInput(InputModel):

    sinkName: str


class SetSinkToUse(CDPMethod[None]):
    """ Sets a sink to be used when the web page requests the browser to choose a
    sink via Presentation API, Remote Playback API, or Cast SDK. """

    INPUT_VALIDATOR = SetSinkToUseInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        sink_name: str
    ):
        super().__init__(
            sinkName=sink_name
        )


class StartDesktopMirroringInput(InputModel):

    sinkName: str


class StartDesktopMirroring(CDPMethod[None]):
    """ Starts mirroring the desktop to the sink. """

    INPUT_VALIDATOR = StartDesktopMirroringInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        sink_name: str
    ):
        super().__init__(
            sinkName=sink_name
        )


class StartTabMirroringInput(InputModel):

    sinkName: str


class StartTabMirroring(CDPMethod[None]):
    """ Starts mirroring the tab to the sink. """

    INPUT_VALIDATOR = StartTabMirroringInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        sink_name: str
    ):
        super().__init__(
            sinkName=sink_name
        )


class StopCastingInput(InputModel):

    sinkName: str


class StopCasting(CDPMethod[None]):
    """ Stops the active Cast session on the sink. """

    INPUT_VALIDATOR = StopCastingInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        sink_name: str
    ):
        super().__init__(
            sinkName=sink_name
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain emulates different environments for the page.
https://chromedevtools.github.io/devtools-protocol/tot/Emulation/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol.base import CDPEvent


class VirtualTimeBudgetExpired(CDPEvent):
    """ Notification sent after the virtual time budget for the current VirtualTimePolicy has run out. """

    ...



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

EventBreakpoints permits setting JavaScript breakpoints on operations and events
occurring in native code invoked from JavaScript. Once breakpoint is hit, it is
reported through Debugger domain, similarly to regular breakpoints being hit.
https://chromedevtools.github.io/devtools-protocol/tot/EventBreakpoints/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations



from .events import LayerPainted, LayerTreeDidChange
from .methods import (
    CompositingReasons,
    Disable,
    Enable,
    LoadSnapshot,
    MakeSnapshot,
    ProfileSnapshot,
    ReleaseSnapshot,
    ReplaySnapshot,
    SnapshotCommandLog,
)
from .types import Layer, LayerId, PaintProfile, PictureTile, ScrollRect, SnapshotId, StickyPositionConstraint

__all__ = [
    LayerId,
    SnapshotId,
    ScrollRect,
    StickyPositionConstraint,
    PictureTile,
    Layer,
    PaintProfile,
    LayerPainted,
    LayerTreeDidChange,
    CompositingReasons,
    Disable,
    Enable,
    LoadSnapshot,
    MakeSnapshot,
    ProfileSnapshot,
    ReleaseSnapshot,
    ReplaySnapshot,
    SnapshotCommandLog,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

The Tethering domain defines methods and events for browser port binding.
https://chromedevtools.github.io/devtools-protocol/tot/Tethering/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol.base import CDPMethod, InputModel


class BindInput(InputModel):

    port: int


class Bind(CDPMethod[None]):
    """ Request browser port binding. """

    INPUT_VALIDATOR = BindInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        port: int
    ):
        super().__init__(
            port=port
        )


class UnbindInput(InputModel):

    port: int


class Unbind(CDPMethod[None]):
    """ Request browser port unbinding. """

    INPUT_VALIDATOR = UnbindInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        port: int
    ):
        super().__init__(
            port=port
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Defines events for background web platform features.
https://chromedevtools.github.io/devtools-protocol/tot/BackgroundService/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    BackgroundService,
)
from cdpkit.protocol.base import CDPEvent


class RecordingStateChanged(CDPEvent):
    """ Called when the recording state for the service has been updated. """

    isRecording: bool
    service: BackgroundService.ServiceName


class BackgroundServiceEventReceived(CDPEvent):
    """ Called with all existing backgroundServiceEvents when enabled, and all new
    events afterwards if enabled and recording. """

    backgroundServiceEvent: BackgroundService.BackgroundServiceEvent



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain exposes CSS read/write operations. All CSS objects (stylesheets, rules, and styles)
have an associated `id` used in subsequent operations on the related object. Each object type has
a specific `id` structure, and those are not interchangeable between objects of different kinds.
CSS objects can be loaded using the `get*ForNode()` calls (which accept a DOM node id). A client
can also keep track of stylesheets via the `styleSheetAdded`/`styleSheetRemoved` events and
subsequently load the required stylesheet contents using the `getStyleSheet[Text]()` methods.
https://chromedevtools.github.io/devtools-protocol/tot/CSS/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    CSSComputedStyleExtraFields,
    CSSCSSAnimationStyle,
    CSSCSSAtRule,
    CSSCSSComputedStyleProperty,
    CSSCSSContainerQuery,
    CSSCSSFunctionConditionNode,
    CSSCSSFunctionNode,
    CSSCSSFunctionParameter,
    CSSCSSFunctionRule,
    CSSCSSKeyframeRule,
    CSSCSSKeyframesRule,
    CSSCSSLayer,
    CSSCSSLayerData,
    CSSCSSMedia,
    CSSCSSPositionTryRule,
    CSSCSSProperty,
    CSSCSSPropertyRegistration,
    CSSCSSPropertyRule,
    CSSCSSRule,
    CSSCSSRuleType,
    CSSCSSScope,
    CSSCSSStartingStyle,
    CSSCSSStyle,
    CSSCSSStyleSheetHeader,
    CSSCSSSupports,
    CSSCSSTryRule,
    CSSFontFace,
    CSSFontVariationAxis,
    CSSInheritedAnimatedStyleEntry,
    CSSInheritedPseudoElementMatches,
    CSSInheritedStyleEntry,
    CSSMediaQuery,
    CSSMediaQueryExpression,
    CSSPlatformFontUsage,
    CSSPseudoElementMatches,
    CSSRuleMatch,
    CSSRuleUsage,
    CSSSelectorList,
    CSSShorthandEntry,
    CSSSourceRange,
    CSSSpecificity,
    CSSStyleDeclarationEdit,
    CSSStyleSheetOrigin,
    CSSValue,
)

StyleSheetOrigin = CSSStyleSheetOrigin
PseudoElementMatches = CSSPseudoElementMatches
CSSAnimationStyle = CSSCSSAnimationStyle
InheritedStyleEntry = CSSInheritedStyleEntry
InheritedAnimatedStyleEntry = CSSInheritedAnimatedStyleEntry
InheritedPseudoElementMatches = CSSInheritedPseudoElementMatches
RuleMatch = CSSRuleMatch
Value = CSSValue
Specificity = CSSSpecificity
SelectorList = CSSSelectorList
CSSStyleSheetHeader = CSSCSSStyleSheetHeader
CSSRule = CSSCSSRule
CSSRuleType = CSSCSSRuleType
RuleUsage = CSSRuleUsage
SourceRange = CSSSourceRange
ShorthandEntry = CSSShorthandEntry
CSSComputedStyleProperty = CSSCSSComputedStyleProperty
ComputedStyleExtraFields = CSSComputedStyleExtraFields
CSSStyle = CSSCSSStyle
CSSProperty = CSSCSSProperty
CSSMedia = CSSCSSMedia
MediaQuery = CSSMediaQuery
MediaQueryExpression = CSSMediaQueryExpression
CSSContainerQuery = CSSCSSContainerQuery
CSSSupports = CSSCSSSupports
CSSScope = CSSCSSScope
CSSLayer = CSSCSSLayer
CSSStartingStyle = CSSCSSStartingStyle
CSSLayerData = CSSCSSLayerData
PlatformFontUsage = CSSPlatformFontUsage
FontVariationAxis = CSSFontVariationAxis
FontFace = CSSFontFace
CSSTryRule = CSSCSSTryRule
CSSPositionTryRule = CSSCSSPositionTryRule
CSSKeyframesRule = CSSCSSKeyframesRule
CSSPropertyRegistration = CSSCSSPropertyRegistration
CSSAtRule = CSSCSSAtRule
CSSPropertyRule = CSSCSSPropertyRule
CSSFunctionParameter = CSSCSSFunctionParameter
CSSFunctionConditionNode = CSSCSSFunctionConditionNode
CSSFunctionNode = CSSCSSFunctionNode
CSSFunctionRule = CSSCSSFunctionRule
CSSKeyframeRule = CSSCSSKeyframeRule
StyleDeclarationEdit = CSSStyleDeclarationEdit



from .events import MessageAdded
from .methods import ClearMessages, Disable, Enable
from .types import ConsoleMessage

__all__ = [
    ConsoleMessage,
    MessageAdded,
    ClearMessages,
    Disable,
    Enable,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Audits domain allows investigation of page violations and possible improvements.
https://chromedevtools.github.io/devtools-protocol/tot/Audits/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    AuditsAffectedCookie,
    AuditsAffectedFrame,
    AuditsAffectedRequest,
    AuditsAttributionReportingIssueDetails,
    AuditsAttributionReportingIssueType,
    AuditsBlockedByResponseIssueDetails,
    AuditsBlockedByResponseReason,
    AuditsBounceTrackingIssueDetails,
    AuditsClientHintIssueDetails,
    AuditsClientHintIssueReason,
    AuditsContentSecurityPolicyIssueDetails,
    AuditsContentSecurityPolicyViolationType,
    AuditsCookieDeprecationMetadataIssueDetails,
    AuditsCookieExclusionReason,
    AuditsCookieIssueDetails,
    AuditsCookieIssueInsight,
    AuditsCookieOperation,
    AuditsCookieWarningReason,
    AuditsCorsIssueDetails,
    AuditsDeprecationIssueDetails,
    AuditsElementAccessibilityIssueDetails,
    AuditsElementAccessibilityIssueReason,
    AuditsFailedRequestInfo,
    AuditsFederatedAuthRequestIssueDetails,
    AuditsFederatedAuthRequestIssueReason,
    AuditsFederatedAuthUserInfoRequestIssueDetails,
    AuditsFederatedAuthUserInfoRequestIssueReason,
    AuditsGenericIssueDetails,
    AuditsGenericIssueErrorType,
    AuditsHeavyAdIssueDetails,
    AuditsHeavyAdReason,
    AuditsHeavyAdResolutionStatus,
    AuditsInsightType,
    AuditsInspectorIssue,
    AuditsInspectorIssueCode,
    AuditsInspectorIssueDetails,
    AuditsIssueId,
    AuditsLowTextContrastIssueDetails,
    AuditsMixedContentIssueDetails,
    AuditsMixedContentResolutionStatus,
    AuditsMixedContentResourceType,
    AuditsNavigatorUserAgentIssueDetails,
    AuditsPartitioningBlobURLInfo,
    AuditsPartitioningBlobURLIssueDetails,
    AuditsPermissionElementIssueDetails,
    AuditsPermissionElementIssueType,
    AuditsPropertyRuleIssueDetails,
    AuditsPropertyRuleIssueReason,
    AuditsQuirksModeIssueDetails,
    AuditsSharedArrayBufferIssueDetails,
    AuditsSharedArrayBufferIssueType,
    AuditsSharedDictionaryError,
    AuditsSharedDictionaryIssueDetails,
    AuditsSourceCodeLocation,
    AuditsSRIMessageSignatureError,
    AuditsSRIMessageSignatureIssueDetails,
    AuditsStylesheetLoadingIssueDetails,
    AuditsStyleSheetLoadingIssueReason,
    AuditsUnencodedDigestError,
    AuditsUnencodedDigestIssueDetails,
    AuditsUserReidentificationIssueDetails,
    AuditsUserReidentificationIssueType,
)

AffectedCookie = AuditsAffectedCookie
AffectedRequest = AuditsAffectedRequest
AffectedFrame = AuditsAffectedFrame
CookieExclusionReason = AuditsCookieExclusionReason
CookieWarningReason = AuditsCookieWarningReason
CookieOperation = AuditsCookieOperation
InsightType = AuditsInsightType
CookieIssueInsight = AuditsCookieIssueInsight
CookieIssueDetails = AuditsCookieIssueDetails
MixedContentResolutionStatus = AuditsMixedContentResolutionStatus
MixedContentResourceType = AuditsMixedContentResourceType
MixedContentIssueDetails = AuditsMixedContentIssueDetails
BlockedByResponseReason = AuditsBlockedByResponseReason
BlockedByResponseIssueDetails = AuditsBlockedByResponseIssueDetails
HeavyAdResolutionStatus = AuditsHeavyAdResolutionStatus
HeavyAdReason = AuditsHeavyAdReason
HeavyAdIssueDetails = AuditsHeavyAdIssueDetails
ContentSecurityPolicyViolationType = AuditsContentSecurityPolicyViolationType
SourceCodeLocation = AuditsSourceCodeLocation
ContentSecurityPolicyIssueDetails = AuditsContentSecurityPolicyIssueDetails
SharedArrayBufferIssueType = AuditsSharedArrayBufferIssueType
SharedArrayBufferIssueDetails = AuditsSharedArrayBufferIssueDetails
LowTextContrastIssueDetails = AuditsLowTextContrastIssueDetails
CorsIssueDetails = AuditsCorsIssueDetails
AttributionReportingIssueType = AuditsAttributionReportingIssueType
SharedDictionaryError = AuditsSharedDictionaryError
SRIMessageSignatureError = AuditsSRIMessageSignatureError
UnencodedDigestError = AuditsUnencodedDigestError
AttributionReportingIssueDetails = AuditsAttributionReportingIssueDetails
QuirksModeIssueDetails = AuditsQuirksModeIssueDetails
NavigatorUserAgentIssueDetails = AuditsNavigatorUserAgentIssueDetails
SharedDictionaryIssueDetails = AuditsSharedDictionaryIssueDetails
SRIMessageSignatureIssueDetails = AuditsSRIMessageSignatureIssueDetails
UnencodedDigestIssueDetails = AuditsUnencodedDigestIssueDetails
GenericIssueErrorType = AuditsGenericIssueErrorType
GenericIssueDetails = AuditsGenericIssueDetails
DeprecationIssueDetails = AuditsDeprecationIssueDetails
BounceTrackingIssueDetails = AuditsBounceTrackingIssueDetails
CookieDeprecationMetadataIssueDetails = AuditsCookieDeprecationMetadataIssueDetails
ClientHintIssueReason = AuditsClientHintIssueReason
FederatedAuthRequestIssueDetails = AuditsFederatedAuthRequestIssueDetails
FederatedAuthRequestIssueReason = AuditsFederatedAuthRequestIssueReason
FederatedAuthUserInfoRequestIssueDetails = AuditsFederatedAuthUserInfoRequestIssueDetails
FederatedAuthUserInfoRequestIssueReason = AuditsFederatedAuthUserInfoRequestIssueReason
ClientHintIssueDetails = AuditsClientHintIssueDetails
FailedRequestInfo = AuditsFailedRequestInfo
PartitioningBlobURLInfo = AuditsPartitioningBlobURLInfo
PartitioningBlobURLIssueDetails = AuditsPartitioningBlobURLIssueDetails
ElementAccessibilityIssueReason = AuditsElementAccessibilityIssueReason
ElementAccessibilityIssueDetails = AuditsElementAccessibilityIssueDetails
StyleSheetLoadingIssueReason = AuditsStyleSheetLoadingIssueReason
StylesheetLoadingIssueDetails = AuditsStylesheetLoadingIssueDetails
PropertyRuleIssueReason = AuditsPropertyRuleIssueReason
PropertyRuleIssueDetails = AuditsPropertyRuleIssueDetails
UserReidentificationIssueType = AuditsUserReidentificationIssueType
UserReidentificationIssueDetails = AuditsUserReidentificationIssueDetails
PermissionElementIssueType = AuditsPermissionElementIssueType
PermissionElementIssueDetails = AuditsPermissionElementIssueDetails
InspectorIssueCode = AuditsInspectorIssueCode
InspectorIssueDetails = AuditsInspectorIssueDetails
IssueId = AuditsIssueId
InspectorIssue = AuditsInspectorIssue



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain exposes DOM read/write operations. Each DOM Node is represented with its mirror object
that has an `id`. This `id` can be used to get additional information on the Node, resolve it into
the JavaScript object wrapper, etc. It is important that client receives DOM events only for the
nodes that are known to the client. Backend keeps track of the nodes that were sent to the client
and never sends the same node twice. It is client's responsibility to collect information about
the nodes that were sent to the client. Note that `iframe` owner elements will return
corresponding document elements as their child nodes.
https://chromedevtools.github.io/devtools-protocol/tot/DOM/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOM,
)
from cdpkit.protocol.base import CDPEvent


class AttributeModified(CDPEvent):
    """ Fired when `Element`'s attribute is modified. """

    nodeId: DOM.NodeId
    name: str
    value: str


class AdoptedStyleSheetsModified(CDPEvent):
    """ Fired when `Element`'s adoptedStyleSheets are modified. """

    nodeId: DOM.NodeId
    adoptedStyleSheets: list[DOM.StyleSheetId] | None = None  # experimental


class AttributeRemoved(CDPEvent):
    """ Fired when `Element`'s attribute is removed. """

    nodeId: DOM.NodeId
    name: str


class CharacterDataModified(CDPEvent):
    """ Mirrors `DOMCharacterDataModified` event. """

    nodeId: DOM.NodeId
    characterData: str


class ChildNodeCountUpdated(CDPEvent):
    """ Fired when `Container`'s child node count has changed. """

    nodeId: DOM.NodeId
    childNodeCount: int


class ChildNodeInserted(CDPEvent):
    """ Mirrors `DOMNodeInserted` event. """

    parentNodeId: DOM.NodeId
    previousNodeId: DOM.NodeId
    node: DOM.Node


class ChildNodeRemoved(CDPEvent):
    """ Mirrors `DOMNodeRemoved` event. """

    parentNodeId: DOM.NodeId
    nodeId: DOM.NodeId


class DistributedNodesUpdated(CDPEvent):
    """ Called when distribution is changed. """

    insertionPointId: DOM.NodeId
    distributedNodes: list[DOM.BackendNode]


class DocumentUpdated(CDPEvent):
    """ Fired when `Document` has been totally updated. Node ids are no longer valid. """

    ...


class InlineStyleInvalidated(CDPEvent):
    """ Fired when `Element`'s inline style is modified via a CSS property modification. """

    nodeIds: list[DOM.NodeId]


class PseudoElementAdded(CDPEvent):
    """ Called when a pseudo element is added to an element. """

    parentId: DOM.NodeId
    pseudoElement: DOM.Node


class TopLayerElementsUpdated(CDPEvent):
    """ Called when top layer elements are changed. """

    ...


class ScrollableFlagUpdated(CDPEvent):
    """ Fired when a node's scrollability state changes. """

    nodeId: DOM.NodeId
    isScrollable: bool


class AffectedByStartingStylesFlagUpdated(CDPEvent):
    """ Fired when a node's starting styles changes. """

    nodeId: DOM.NodeId
    affectedByStartingStyles: bool


class PseudoElementRemoved(CDPEvent):
    """ Called when a pseudo element is removed from an element. """

    parentId: DOM.NodeId
    pseudoElementId: DOM.NodeId


class SetChildNodes(CDPEvent):
    """ Fired when backend wants to provide client with the missing DOM structure. This happens upon
    most of the calls requesting node ids. """

    parentId: DOM.NodeId
    nodes: list[DOM.Node]


class ShadowRootPopped(CDPEvent):
    """ Called when shadow root is popped from the element. """

    hostId: DOM.NodeId
    rootId: DOM.NodeId


class ShadowRootPushed(CDPEvent):
    """ Called when shadow root is pushed into the element. """

    hostId: DOM.NodeId
    root: DOM.Node



from .events import DialogClosed, DialogShown
from .methods import ClickDialogButton, Disable, DismissDialog, Enable, OpenUrl, ResetCooldown, SelectAccount
from .types import Account, AccountUrlType, DialogButton, DialogType, LoginState

__all__ = [
    LoginState,
    DialogType,
    DialogButton,
    AccountUrlType,
    Account,
    DialogShown,
    DialogClosed,
    Enable,
    Disable,
    SelectAccount,
    ClickDialogButton,
    OpenUrl,
    DismissDialog,
    ResetCooldown,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/DeviceAccess/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DeviceAccessDeviceId,
    DeviceAccessPromptDevice,
    DeviceAccessRequestId,
)

RequestId = DeviceAccessRequestId
DeviceId = DeviceAccessDeviceId
PromptDevice = DeviceAccessPromptDevice
